@@ -87,8 +87,14 @@ pub struct LineFilterConfig {
     pub skip_admonitions: bool,
     /// Skip lines inside MkDocs content tabs (=== "Tab")
     pub skip_content_tabs: bool,
+    /// Skip lines inside HTML blocks with markdown attribute (MkDocs grid cards, etc.)
+    pub skip_mkdocs_html_markdown: bool,
     /// Skip lines inside definition lists (:  definition)
     pub skip_definition_lists: bool,
+    /// Skip lines inside Obsidian comments (%%...%%)
+    pub skip_obsidian_comments: bool,
+    /// Skip lines inside PyMdown Blocks (/// ... ///, MkDocs flavor only)
+    pub skip_pymdown_blocks: bool,
 }
 
 impl LineFilterConfig {
@@ -217,15 +223,25 @@ impl LineFilterConfig {
         self
     }
 
-    /// Skip lines inside any MkDocs container (admonitions or content tabs)
+    /// Skip lines inside HTML blocks with markdown attribute (MkDocs grid cards, etc.)
     ///
-    /// This is a convenience method that enables both `skip_admonitions` and
-    /// `skip_content_tabs`. MkDocs containers use 4-space indented content
-    /// which may need special handling to preserve structure.
+    /// These blocks contain markdown-enabled HTML which may have custom styling rules.
+    #[must_use]
+    pub fn skip_mkdocs_html_markdown(mut self) -> Self {
+        self.skip_mkdocs_html_markdown = true;
+        self
+    }
+
+    /// Skip lines inside any MkDocs container (admonitions, content tabs, or markdown HTML divs)
+    ///
+    /// This is a convenience method that enables `skip_admonitions`,
+    /// `skip_content_tabs`, and `skip_mkdocs_html_markdown`. MkDocs containers use
+    /// 4-space indented content which may need special handling to preserve structure.
     #[must_use]
     pub fn skip_mkdocs_containers(mut self) -> Self {
         self.skip_admonitions = true;
         self.skip_content_tabs = true;
+        self.skip_mkdocs_html_markdown = true;
         self
     }
 
@@ -239,6 +255,27 @@ impl LineFilterConfig {
         self
     }
 
+    /// Skip lines inside Obsidian comments (%%...%%)
+    ///
+    /// Obsidian comments are content hidden from rendering and most
+    /// markdown rules should not process them.
+    #[must_use]
+    pub fn skip_obsidian_comments(mut self) -> Self {
+        self.skip_obsidian_comments = true;
+        self
+    }
+
+    /// Skip lines inside PyMdown Blocks (/// ... ///)
+    ///
+    /// PyMdown Blocks are structured content blocks used by the PyMdown Extensions
+    /// library for captions, collapsible details, admonitions, and other features.
+    /// Rules may need to skip them for accurate processing.
+    #[must_use]
+    pub fn skip_pymdown_blocks(mut self) -> Self {
+        self.skip_pymdown_blocks = true;
+        self
+    }
+
     /// Check if a line should be filtered out based on this configuration
     fn should_filter(&self, line_info: &LineInfo) -> bool {
         (self.skip_front_matter && line_info.in_front_matter)
@@ -253,7 +290,10 @@ impl LineFilterConfig {
             || (self.skip_mdx_comments && line_info.in_mdx_comment)
             || (self.skip_admonitions && line_info.in_admonition)
             || (self.skip_content_tabs && line_info.in_content_tab)
+            || (self.skip_mkdocs_html_markdown && line_info.in_mkdocs_html_markdown)
             || (self.skip_definition_lists && line_info.in_definition_list)
+            || (self.skip_obsidian_comments && line_info.in_obsidian_comment)
+            || (self.skip_pymdown_blocks && line_info.in_pymdown_block)
     }
 }
 
@@ -262,7 +302,6 @@ pub struct FilteredLinesIter<'a> {
     ctx: &'a LintContext<'a>,
     config: LineFilterConfig,
     current_index: usize,
-    content_lines: Vec<&'a str>,
 }
 
 impl<'a> FilteredLinesIter<'a> {
@@ -272,7 +311,6 @@ impl<'a> FilteredLinesIter<'a> {
             ctx,
             config,
             current_index: 0,
-            content_lines: ctx.content.lines().collect(),
         }
     }
 }
@@ -282,6 +320,7 @@ impl<'a> Iterator for FilteredLinesIter<'a> {
 
     fn next(&mut self) -> Option<Self::Item> {
         let lines = &self.ctx.lines;
+        let raw_lines = self.ctx.raw_lines();
 
         while self.current_index < lines.len() {
             let idx = self.current_index;
@@ -292,8 +331,8 @@ impl<'a> Iterator for FilteredLinesIter<'a> {
                 continue;
             }
 
-            // Get the actual line content from the document
-            let line_content = self.content_lines.get(idx).copied().unwrap_or("");
+            // Get the actual line content from pre-split lines
+            let line_content = raw_lines.get(idx).copied().unwrap_or("");
 
             // Return the filtered line with 1-indexed line number
             return Some(FilteredLine {
@@ -455,11 +494,18 @@ impl<'a> FilteredLinesBuilder<'a> {
         self
     }
 
-    /// Skip lines inside any MkDocs container (admonitions or content tabs)
+    /// Skip lines inside HTML blocks with markdown attribute (MkDocs grid cards, etc.)
+    #[must_use]
+    pub fn skip_mkdocs_html_markdown(mut self) -> Self {
+        self.config = self.config.skip_mkdocs_html_markdown();
+        self
+    }
+
+    /// Skip lines inside any MkDocs container (admonitions, content tabs, or markdown HTML divs)
     ///
-    /// This is a convenience method that enables both `skip_admonitions` and
-    /// `skip_content_tabs`. MkDocs containers use 4-space indented content
-    /// which may need special handling to preserve structure.
+    /// This is a convenience method that enables `skip_admonitions`,
+    /// `skip_content_tabs`, and `skip_mkdocs_html_markdown`. MkDocs containers use
+    /// 4-space indented content which may need special handling to preserve structure.
     #[must_use]
     pub fn skip_mkdocs_containers(mut self) -> Self {
         self.config = self.config.skip_mkdocs_containers();
@@ -472,6 +518,20 @@ impl<'a> FilteredLinesBuilder<'a> {
         self.config = self.config.skip_definition_lists();
         self
     }
+
+    /// Skip lines inside Obsidian comments (%%...%%)
+    #[must_use]
+    pub fn skip_obsidian_comments(mut self) -> Self {
+        self.config = self.config.skip_obsidian_comments();
+        self
+    }
+
+    /// Skip lines inside PyMdown Blocks (/// ... ///)
+    #[must_use]
+    pub fn skip_pymdown_blocks(mut self) -> Self {
+        self.config = self.config.skip_pymdown_blocks();
+        self
+    }
 }
 
 impl<'a> IntoIterator for FilteredLinesBuilder<'a> {
@@ -1207,4 +1267,666 @@ Content."#;
             "Should NOT exclude brace content in standard markdown"
         );
     }
+
+    // ==================== Obsidian Comment Tests ====================
+
+    #[test]
+    fn test_skip_obsidian_comments_simple_inline() {
+        // Simple inline comment: text %%hidden%% text
+        let content = r#"# Heading
+
+This is visible %%this is hidden%% and visible again.
+
+More content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // All lines should be included - inline comments don't hide entire lines
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("This is visible")),
+            "Should include line with inline comment"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("More content")),
+            "Should include content after comment"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_multiline_block() {
+        // Multi-line comment block
+        let content = r#"# Heading
+
+%%
+This is a multi-line
+comment block
+%%
+
+Content after."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Should include content outside the comment block
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content after")),
+            "Should include content after comment block"
+        );
+
+        // Lines inside the comment block should be excluded
+        assert!(
+            !lines.iter().any(|l| l.content.contains("This is a multi-line")),
+            "Should exclude multi-line comment content"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("comment block")),
+            "Should exclude multi-line comment content"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_in_code_block() {
+        // %% inside code blocks should NOT be treated as comments
+        let content = r#"# Heading
+
+```
+%% This is NOT a comment
+It's inside a code block
+%%
+```
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx
+            .filtered_lines()
+            .skip_obsidian_comments()
+            .skip_code_blocks()
+            .into_iter()
+            .collect();
+
+        // The code block content should be excluded by skip_code_blocks, not by obsidian comments
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content after code block"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_in_html_comment() {
+        // %% inside HTML comments should NOT be treated as Obsidian comments
+        let content = r#"# Heading
+
+<!-- %% This is inside HTML comment %% -->
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx
+            .filtered_lines()
+            .skip_obsidian_comments()
+            .skip_html_comments()
+            .into_iter()
+            .collect();
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_empty() {
+        // Empty comment: %%%%
+        let content = r#"# Heading
+
+%%%% empty comment
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Empty comments should be handled gracefully
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_unclosed() {
+        // Unclosed comment extends to end of document
+        let content = r#"# Heading
+
+%% starts but never ends
+This should be hidden
+Until end of document"#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Should include content before the unclosed comment
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading before unclosed comment"
+        );
+
+        // Content after the %% should be excluded
+        assert!(
+            !lines.iter().any(|l| l.content.contains("This should be hidden")),
+            "Should exclude content in unclosed comment"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("Until end of document")),
+            "Should exclude content until end of document"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_multiple_on_same_line() {
+        // Multiple comments on same line
+        let content = r#"# Heading
+
+First %%hidden1%% middle %%hidden2%% last
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Line should still be included (inline comments)
+        assert!(
+            lines.iter().any(|l| l.content.contains("First")),
+            "Should include line with multiple inline comments"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("middle")),
+            "Should include visible text between comments"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_at_start_of_line() {
+        // Comment at start of line
+        let content = r#"# Heading
+
+%%comment at start%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_at_end_of_line() {
+        // Comment at end of line
+        let content = r#"# Heading
+
+Some text %%comment at end%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("Some text")),
+            "Should include text before comment"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_with_markdown_inside() {
+        // Comments containing special markdown
+        let content = r#"# Heading
+
+%%
+# hidden heading
+[hidden link](url)
+**hidden bold**
+%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        assert!(
+            !lines.iter().any(|l| l.content.contains("# hidden heading")),
+            "Should exclude heading inside comment"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("[hidden link]")),
+            "Should exclude link inside comment"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("**hidden bold**")),
+            "Should exclude bold inside comment"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_with_unicode() {
+        // Unicode content inside comments
+        let content = r#"# Heading
+
+%%日本語コメント%%
+
+%%Комментарий%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Lines with only comments should be handled properly
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_triple_percent() {
+        // Odd number of percent signs: %%%
+        let content = r#"# Heading
+
+%%% odd percent
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // Should handle gracefully - the %%% starts a comment, single % is content
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_not_in_standard_flavor() {
+        // Obsidian comments should NOT be detected in Standard flavor
+        let content = r#"# Heading
+
+%%this is not hidden in standard%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // In Standard flavor, %% is just text - nothing should be filtered
+        assert!(
+            lines.iter().any(|l| l.content.contains("%%this is not hidden")),
+            "Should NOT hide %% content in Standard flavor"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_integration_with_other_filters() {
+        // Test combining with frontmatter and code block filters
+        let content = r#"---
+title: Test
+---
+
+# Heading
+
+```
+code
+```
+
+%%hidden comment%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx
+            .filtered_lines()
+            .skip_front_matter()
+            .skip_code_blocks()
+            .skip_obsidian_comments()
+            .into_iter()
+            .collect();
+
+        // Should skip frontmatter, code blocks, and Obsidian comments
+        assert!(
+            !lines.iter().any(|l| l.content.contains("title: Test")),
+            "Should skip frontmatter"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content == "code"),
+            "Should skip code block content"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_whole_line_only() {
+        // Multi-line comment should only mark lines entirely within the comment
+        let content = "start %%\nfully hidden\n%% end";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // First line starts before comment, should be included
+        assert!(
+            lines.iter().any(|l| l.content.contains("start")),
+            "First line should be included (starts outside comment)"
+        );
+        // Middle line is entirely within comment, should be excluded
+        assert!(
+            !lines.iter().any(|l| l.content == "fully hidden"),
+            "Middle line should be excluded (entirely within comment)"
+        );
+        // Last line ends after comment, should be included
+        assert!(
+            lines.iter().any(|l| l.content.contains("end")),
+            "Last line should be included (ends outside comment)"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_in_inline_code() {
+        // %% inside inline code spans should NOT be treated as comments
+        let content = r#"# Heading
+
+The syntax is `%%comment%%` in Obsidian.
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // The line with code span should be included
+        assert!(
+            lines.iter().any(|l| l.content.contains("The syntax is")),
+            "Should include line with %% in code span"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("in Obsidian")),
+            "Should include text after code span"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_in_inline_code_multi_backtick() {
+        // %% inside inline code spans with multiple backticks should NOT be treated as comments
+        let content = r#"# Heading
+
+The syntax is ``%%comment%%`` in Obsidian.
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("The syntax is")),
+            "Should include line with %% in multi-backtick code span"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content after code span"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_consecutive_blocks() {
+        // Multiple consecutive comment blocks
+        let content = r#"# Heading
+
+%%comment 1%%
+
+%%comment 2%%
+
+Content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content")),
+            "Should include content after comments"
+        );
+    }
+
+    #[test]
+    fn test_skip_obsidian_comments_spanning_many_lines() {
+        // Comment block spanning many lines
+        let content = r#"# Title
+
+%%
+Line 1 of comment
+Line 2 of comment
+Line 3 of comment
+Line 4 of comment
+Line 5 of comment
+%%
+
+After comment."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_obsidian_comments().into_iter().collect();
+
+        // All lines inside the comment should be excluded
+        for i in 1..=5 {
+            assert!(
+                !lines
+                    .iter()
+                    .any(|l| l.content.contains(&format!("Line {i} of comment"))),
+                "Should exclude line {i} of comment"
+            );
+        }
+
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Title")),
+            "Should include title"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("After comment")),
+            "Should include content after comment"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_comment_line_info_field() {
+        // Verify the in_obsidian_comment field is set correctly
+        let content = "visible\n%%\nhidden\n%%\nvisible";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+
+        // Line 0: visible - should NOT be in comment
+        assert!(
+            !ctx.lines[0].in_obsidian_comment,
+            "Line 0 should not be marked as in_obsidian_comment"
+        );
+
+        // Line 2: hidden - should be in comment
+        assert!(
+            ctx.lines[2].in_obsidian_comment,
+            "Line 2 (hidden) should be marked as in_obsidian_comment"
+        );
+
+        // Line 4: visible - should NOT be in comment
+        assert!(
+            !ctx.lines[4].in_obsidian_comment,
+            "Line 4 should not be marked as in_obsidian_comment"
+        );
+    }
+
+    // ==================== PyMdown Blocks Filter Tests ====================
+
+    #[test]
+    fn test_skip_pymdown_blocks_basic() {
+        // Basic PyMdown block (caption)
+        let content = r#"# Heading
+
+/// caption
+Table caption here.
+///
+
+Content after."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_pymdown_blocks().into_iter().collect();
+
+        // Should include heading and content after
+        assert!(
+            lines.iter().any(|l| l.content.contains("# Heading")),
+            "Should include heading"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Content after")),
+            "Should include content after block"
+        );
+
+        // Should NOT include content inside the block
+        assert!(
+            !lines.iter().any(|l| l.content.contains("Table caption")),
+            "Should exclude content inside block"
+        );
+    }
+
+    #[test]
+    fn test_skip_pymdown_blocks_details() {
+        // Details block with summary
+        let content = r#"# Heading
+
+/// details | Click to expand
+    open: True
+Hidden content here.
+More hidden content.
+///
+
+Visible content."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_pymdown_blocks().into_iter().collect();
+
+        assert!(
+            !lines.iter().any(|l| l.content.contains("Hidden content")),
+            "Should exclude hidden content"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("open: True")),
+            "Should exclude YAML options"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("Visible content")),
+            "Should include visible content"
+        );
+    }
+
+    #[test]
+    fn test_skip_pymdown_blocks_nested() {
+        // Nested blocks
+        let content = r#"# Title
+
+/// details | Outer
+Outer content.
+
+  /// caption
+  Inner caption.
+  ///
+
+More outer content.
+///
+
+After all blocks."#;
+        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        let lines: Vec<_> = ctx.filtered_lines().skip_pymdown_blocks().into_iter().collect();
+
+        assert!(
+            !lines.iter().any(|l| l.content.contains("Outer content")),
+            "Should exclude outer block content"
+        );
+        assert!(
+            !lines.iter().any(|l| l.content.contains("Inner caption")),
+            "Should exclude inner block content"
+        );
+        assert!(
+            lines.iter().any(|l| l.content.contains("After all blocks")),
+            "Should include content after all blocks"
+        );
+    }
+
+    #[test]
+    fn test_pymdown_block_line_info_field() {
+        // Verify the in_pymdown_block field is set correctly
+        let content = "visible\n/// caption\nhidden\n///\nvisible";
+        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+
+        // Line 0: visible - should NOT be in block
+        assert!(
+            !ctx.lines[0].in_pymdown_block,
+            "Line 0 should not be marked as in_pymdown_block"
+        );
+
+        // Line 1: /// caption - should be in block
+        assert!(
+            ctx.lines[1].in_pymdown_block,
+            "Line 1 (/// caption) should be marked as in_pymdown_block"
+        );
+
+        // Line 2: hidden - should be in block
+        assert!(
+            ctx.lines[2].in_pymdown_block,
+            "Line 2 (hidden) should be marked as in_pymdown_block"
+        );
+
+        // Line 3: /// - closing should still be in block range
+        assert!(
+            ctx.lines[3].in_pymdown_block,
+            "Line 3 (closing ///) should be marked as in_pymdown_block"
+        );
+
+        // Line 4: visible - should NOT be in block
+        assert!(
+            !ctx.lines[4].in_pymdown_block,
+            "Line 4 should not be marked as in_pymdown_block"
+        );
+    }
+
+    #[test]
+    fn test_pymdown_blocks_only_for_mkdocs_flavor() {
+        // PyMdown blocks should only be detected for MkDocs flavor
+        let content = "/// caption\nCaption text\n///";
+
+        // Test with MkDocs flavor - should detect block
+        let ctx_mkdocs = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        assert!(
+            ctx_mkdocs.lines[1].in_pymdown_block,
+            "MkDocs flavor should detect pymdown blocks"
+        );
+
+        // Test with Standard flavor - should NOT detect block
+        let ctx_standard = LintContext::new(content, MarkdownFlavor::Standard, None);
+        assert!(
+            !ctx_standard.lines[1].in_pymdown_block,
+            "Standard flavor should NOT detect pymdown blocks"
+        );
+    }
 }
