@@ -1,8 +1,10 @@
+pub mod code_block_tools;
 pub mod config;
 pub mod exit_codes;
 pub mod filtered_lines;
 pub mod fix_coordinator;
 pub mod inline_config;
+pub mod linguist_data;
 pub mod lint_context;
 pub mod markdownlint_config;
 pub mod profiling;
@@ -253,12 +255,14 @@ pub fn lint_and_index(
         return (Ok(warnings), file_index);
     }
 
-    // Parse inline configuration comments once
-    let inline_config = crate::inline_config::InlineConfig::from_content(content);
+    // Parse LintContext once (includes inline config parsing)
+    let lint_ctx = crate::lint_context::LintContext::new(content, flavor, source_file);
+    let inline_config = lint_ctx.inline_config();
 
     // Export inline config data to FileIndex for cross-file rule filtering
-    let (file_disabled, line_disabled) = inline_config.export_for_file_index();
+    let (file_disabled, persistent_transitions, line_disabled) = inline_config.export_for_file_index();
     file_index.file_disabled_rules = file_disabled;
+    file_index.persistent_transitions = persistent_transitions;
     file_index.line_disabled_rules = line_disabled;
 
     // Analyze content characteristics for rule filtering
@@ -274,9 +278,6 @@ pub fn lint_and_index(
     let _total_rules = rules.len();
     let _applicable_count = applicable_rules.len();
 
-    // Parse LintContext once with the provided flavor
-    let lint_ctx = crate::lint_context::LintContext::new(content, flavor, source_file);
-
     #[cfg(not(target_arch = "wasm32"))]
     let profile_rules = std::env::var("RUMDL_PROFILE_RULES").is_ok();
     #[cfg(target_arch = "wasm32")]
@@ -286,7 +287,7 @@ pub fn lint_and_index(
     // then recreate only the affected rules. Works for ALL rules without per-rule changes.
     let inline_overrides = inline_config.get_all_rule_configs();
     let merged_config = if !inline_overrides.is_empty() {
-        config.map(|c| c.merge_with_inline_config(&inline_config))
+        config.map(|c| c.merge_with_inline_config(inline_config))
     } else {
         None
     };
