@@ -156,6 +156,11 @@ impl Rule for MD004UnorderedListStyle {
                 if let Some(line_info) = ctx.line_info(item_line)
                     && let Some(list_item) = &line_info.list_item
                 {
+                    // Skip lines inside PyMdown blocks (MkDocs flavor)
+                    if line_info.in_pymdown_block {
+                        continue;
+                    }
+
                     // Skip ordered list items - we only care about unordered ones
                     if list_item.is_ordered {
                         continue;
