@@ -85,11 +85,15 @@ impl Rule for MD009TrailingSpaces {
 
         let mut warnings = Vec::new();
 
-        // Store lines in a Vec only for accessing previous line (for list item check)
-        // This is still necessary due to the need to look back at prev_line
-        let lines: Vec<&str> = content.lines().collect();
+        // Use pre-computed lines (needed for looking back at prev_line)
+        let lines = ctx.raw_lines();
 
         for (line_num, &line) in lines.iter().enumerate() {
+            // Skip lines inside PyMdown blocks (MkDocs flavor)
+            if ctx.line_info(line_num + 1).is_some_and(|info| info.in_pymdown_block) {
+                continue;
+            }
+
             let line_is_ascii = line.is_ascii();
             let trailing_spaces = if line_is_ascii {
                 Self::count_trailing_spaces_ascii(line)
@@ -239,8 +243,8 @@ impl Rule for MD009TrailingSpaces {
         }
 
         // For complex cases, we need line-by-line processing but with optimizations
-        // We need to collect lines since we need to look at previous lines for list item checks
-        let lines: Vec<&str> = content.lines().collect();
+        // Use pre-computed lines since we need to look at previous lines for list item checks
+        let lines = ctx.raw_lines();
         let mut result = String::with_capacity(content.len()); // Pre-allocate capacity
 
         for (i, line) in lines.iter().enumerate() {
