@@ -1,6 +1,10 @@
 /// Rule MD018: No missing space after ATX heading marker
 ///
 /// See [docs/md018.md](../../docs/md018.md) for full documentation, configuration, and examples.
+mod md018_config;
+
+pub use md018_config::MD018Config;
+
 use crate::config::MarkdownFlavor;
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::range_utils::calculate_single_line_range;
@@ -15,8 +19,16 @@ const UNICODE_HASHTAG_PATTERN_STR: &str = r"^#[\u{FE0F}\u{20E3}]";
 // whitespace, or punctuation (not alphanumeric continuation)
 const MAGICLINK_REF_PATTERN_STR: &str = r"^#\d+(?:\s|[^a-zA-Z0-9]|$)";
 
+// Obsidian tag pattern: #tagname, #project/active, #my-tag_2023, etc.
+// Obsidian tags start with # followed by a non-digit, non-space character,
+// then any combination of word characters, hyphens, underscores, and slashes.
+// Tags cannot start with a number.
+const OBSIDIAN_TAG_PATTERN_STR: &str = r"^#[^\d\s#][^\s#]*(?:\s|$)";
+
 #[derive(Clone)]
-pub struct MD018NoMissingSpaceAtx;
+pub struct MD018NoMissingSpaceAtx {
+    config: MD018Config,
+}
 
 impl Default for MD018NoMissingSpaceAtx {
     fn default() -> Self {
@@ -26,7 +38,13 @@ impl Default for MD018NoMissingSpaceAtx {
 
 impl MD018NoMissingSpaceAtx {
     pub fn new() -> Self {
-        Self
+        Self {
+            config: MD018Config::default(),
+        }
+    }
+
+    pub fn from_config_struct(config: MD018Config) -> Self {
+        Self { config }
     }
 
     /// Check if a line is a MagicLink-style issue/PR reference (e.g., #123, #10)
@@ -35,6 +53,12 @@ impl MD018NoMissingSpaceAtx {
         get_cached_regex(MAGICLINK_REF_PATTERN_STR).is_ok_and(|re| re.is_match(line.trim_start()))
     }
 
+    /// Check if a line is an Obsidian tag (e.g., #tagname, #project/active)
+    /// Used by Obsidian flavor to skip tag syntax
+    fn is_obsidian_tag(line: &str) -> bool {
+        get_cached_regex(OBSIDIAN_TAG_PATTERN_STR).is_ok_and(|re| re.is_match(line.trim_start()))
+    }
+
     /// Check if an ATX heading line is missing space after the marker
     fn check_atx_heading_line(&self, line: &str, flavor: MarkdownFlavor) -> Option<(usize, String)> {
         // Look for ATX marker at start of line (with optional indentation)
@@ -103,9 +127,15 @@ impl MD018NoMissingSpaceAtx {
                 return None;
             }
 
-            // MkDocs flavor: skip MagicLink-style issue/PR refs (#123, #10, etc.)
+            // MagicLink config: skip MagicLink-style issue/PR refs (#123, #10, etc.)
             // MagicLink only uses single #, so check hash_count == 1
-            if flavor == MarkdownFlavor::MkDocs && hash_count == 1 && Self::is_magiclink_ref(line) {
+            if self.config.magiclink && hash_count == 1 && Self::is_magiclink_ref(line) {
+                return None;
+            }
+
+            // Obsidian flavor: skip tag syntax (#tagname, #project/active, etc.)
+            // Obsidian tags only use single #
+            if flavor == MarkdownFlavor::Obsidian && hash_count == 1 && Self::is_obsidian_tag(line) {
                 return None;
             }
 
@@ -157,8 +187,8 @@ impl Rule for MD018NoMissingSpaceAtx {
 
         // Check all lines that have ATX headings from cached info
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
-            // Skip lines inside HTML blocks or HTML comments (e.g., CSS selectors like #id)
-            if line_info.in_html_block || line_info.in_html_comment {
+            // Skip lines inside HTML blocks, HTML comments, or PyMdown blocks
+            if line_info.in_html_block || line_info.in_html_comment || line_info.in_pymdown_block {
                 continue;
             }
 
@@ -186,8 +216,13 @@ impl Rule for MD018NoMissingSpaceAtx {
                         continue;
                     }
 
-                    // MkDocs flavor: skip MagicLink-style issue/PR refs (#123, #10, etc.)
-                    if ctx.flavor == MarkdownFlavor::MkDocs && heading.level == 1 && Self::is_magiclink_ref(line) {
+                    // MagicLink config: skip MagicLink-style issue/PR refs (#123, #10, etc.)
+                    if self.config.magiclink && heading.level == 1 && Self::is_magiclink_ref(line) {
+                        continue;
+                    }
+
+                    // Obsidian flavor: skip tag syntax (#tagname, #project/active, etc.)
+                    if ctx.flavor == MarkdownFlavor::Obsidian && heading.level == 1 && Self::is_obsidian_tag(line) {
                         continue;
                     }
 
@@ -279,12 +314,20 @@ impl Rule for MD018NoMissingSpaceAtx {
                         .map(|re| re.is_match(trimmed))
                         .unwrap_or(false);
 
-                    // MkDocs flavor: skip MagicLink-style issue/PR refs (#123, #10, etc.)
-                    let is_magiclink =
-                        ctx.flavor == MarkdownFlavor::MkDocs && heading.level == 1 && Self::is_magiclink_ref(line);
+                    // MagicLink config: skip MagicLink-style issue/PR refs (#123, #10, etc.)
+                    let is_magiclink = self.config.magiclink && heading.level == 1 && Self::is_magiclink_ref(line);
+
+                    // Obsidian flavor: skip tag syntax (#tagname, #project/active, etc.)
+                    let is_obsidian_tag =
+                        ctx.flavor == MarkdownFlavor::Obsidian && heading.level == 1 && Self::is_obsidian_tag(line);
 
                     // Only attempt fix if not a special pattern
-                    if !is_emoji && !is_unicode && !is_magiclink && trimmed.len() > heading.marker.len() {
+                    if !is_emoji
+                        && !is_unicode
+                        && !is_magiclink
+                        && !is_obsidian_tag
+                        && trimmed.len() > heading.marker.len()
+                    {
                         let after_marker = &trimmed[heading.marker.len()..];
                         if !after_marker.is_empty() && !after_marker.starts_with(' ') && !after_marker.starts_with('\t')
                         {
@@ -337,11 +380,20 @@ impl Rule for MD018NoMissingSpaceAtx {
         self
     }
 
-    fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
+    fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        Box::new(MD018NoMissingSpaceAtx::new())
+        let rule_config = crate::rule_config_serde::load_rule_config::<MD018Config>(config);
+        Box::new(MD018NoMissingSpaceAtx::from_config_struct(rule_config))
+    }
+
+    fn default_config_section(&self) -> Option<(String, toml::Value)> {
+        let json_value = serde_json::to_value(&self.config).ok()?;
+        Some((
+            self.name().to_string(),
+            crate::rule_config_serde::json_to_toml_value(&json_value)?,
+        ))
     }
 }
 
@@ -352,7 +404,7 @@ mod tests {
 
     #[test]
     fn test_basic_functionality() {
-        let rule = MD018NoMissingSpaceAtx;
+        let rule = MD018NoMissingSpaceAtx::new();
 
         // Test with correct space
         let content = "# Heading 1\n## Heading 2\n### Heading 3";
@@ -939,62 +991,65 @@ More content.
 
     #[test]
     fn test_mkdocs_magiclink_skips_numeric_refs() {
-        // MkDocs flavor should skip MagicLink-style issue/PR refs (#123, #10, etc.)
-        let rule = MD018NoMissingSpaceAtx::new();
+        // With magiclink config enabled, should skip MagicLink-style issue/PR refs (#123, #10, etc.)
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
-        // These numeric patterns should be SKIPPED in MkDocs flavor
+        // These numeric patterns should be SKIPPED with magiclink enabled
         assert!(
-            rule.check_atx_heading_line("#10", MarkdownFlavor::MkDocs).is_none(),
-            "#10 should be skipped in MkDocs flavor (MagicLink issue ref)"
+            rule.check_atx_heading_line("#10", MarkdownFlavor::Standard).is_none(),
+            "#10 should be skipped with magiclink config (MagicLink issue ref)"
         );
         assert!(
-            rule.check_atx_heading_line("#123", MarkdownFlavor::MkDocs).is_none(),
-            "#123 should be skipped in MkDocs flavor (MagicLink issue ref)"
+            rule.check_atx_heading_line("#123", MarkdownFlavor::Standard).is_none(),
+            "#123 should be skipped with magiclink config (MagicLink issue ref)"
         );
         assert!(
-            rule.check_atx_heading_line("#10 discusses the issue", MarkdownFlavor::MkDocs)
+            rule.check_atx_heading_line("#10 discusses the issue", MarkdownFlavor::Standard)
                 .is_none(),
-            "#10 followed by text should be skipped in MkDocs flavor"
+            "#10 followed by text should be skipped with magiclink config"
         );
         assert!(
-            rule.check_atx_heading_line("#37.", MarkdownFlavor::MkDocs).is_none(),
-            "#37 followed by punctuation should be skipped in MkDocs flavor"
+            rule.check_atx_heading_line("#37.", MarkdownFlavor::Standard).is_none(),
+            "#37 followed by punctuation should be skipped with magiclink config"
         );
     }
 
     #[test]
     fn test_mkdocs_magiclink_still_flags_non_numeric() {
-        // MkDocs flavor should still flag non-numeric patterns
-        let rule = MD018NoMissingSpaceAtx::new();
+        // With magiclink config enabled, should still flag non-numeric patterns
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
-        // Non-numeric patterns should still be flagged even in MkDocs flavor
+        // Non-numeric patterns should still be flagged even with magiclink enabled
         assert!(
-            rule.check_atx_heading_line("#Summary", MarkdownFlavor::MkDocs)
+            rule.check_atx_heading_line("#Summary", MarkdownFlavor::Standard)
                 .is_some(),
-            "#Summary should still be flagged in MkDocs flavor"
+            "#Summary should still be flagged with magiclink config"
         );
         assert!(
-            rule.check_atx_heading_line("#hello", MarkdownFlavor::MkDocs).is_some(),
-            "#hello should still be flagged in MkDocs flavor"
+            rule.check_atx_heading_line("#hello", MarkdownFlavor::Standard)
+                .is_some(),
+            "#hello should still be flagged with magiclink config"
         );
         assert!(
-            rule.check_atx_heading_line("#10abc", MarkdownFlavor::MkDocs).is_some(),
-            "#10abc (mixed) should still be flagged in MkDocs flavor"
+            rule.check_atx_heading_line("#10abc", MarkdownFlavor::Standard)
+                .is_some(),
+            "#10abc (mixed) should still be flagged with magiclink config"
         );
     }
 
     #[test]
     fn test_mkdocs_magiclink_only_single_hash() {
         // MagicLink only uses single #, so ##10 should still be flagged
-        let rule = MD018NoMissingSpaceAtx::new();
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
         assert!(
-            rule.check_atx_heading_line("##10", MarkdownFlavor::MkDocs).is_some(),
-            "##10 should be flagged in MkDocs flavor (only single # is MagicLink)"
+            rule.check_atx_heading_line("##10", MarkdownFlavor::Standard).is_some(),
+            "##10 should be flagged with magiclink config (only single # is MagicLink)"
         );
         assert!(
-            rule.check_atx_heading_line("###123", MarkdownFlavor::MkDocs).is_some(),
-            "###123 should be flagged in MkDocs flavor"
+            rule.check_atx_heading_line("###123", MarkdownFlavor::Standard)
+                .is_some(),
+            "###123 should be flagged with magiclink config"
         );
     }
 
@@ -1015,8 +1070,8 @@ More content.
 
     #[test]
     fn test_mkdocs_magiclink_full_check() {
-        // Integration test: verify MkDocs flavor skips MagicLink refs through full check() flow
-        let rule = MD018NoMissingSpaceAtx::new();
+        // Integration test: verify magiclink config skips MagicLink refs through full check() flow
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
         let content = r#"# PRs that are helpful for context
 
@@ -1027,48 +1082,48 @@ More content.
 ##Introduction
 "#;
 
-        // MkDocs flavor - should skip #10 and #37, but flag #Summary and ##Introduction
-        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        // With magiclink enabled - should skip #10 and #37, but flag #Summary and ##Introduction
+        let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         let flagged_lines: Vec<usize> = result.iter().map(|w| w.line).collect();
         assert!(
             !flagged_lines.contains(&3),
-            "#10 should NOT be flagged in MkDocs flavor"
+            "#10 should NOT be flagged with magiclink config"
         );
         assert!(
             flagged_lines.contains(&5),
-            "#Summary SHOULD be flagged in MkDocs flavor"
+            "#Summary SHOULD be flagged with magiclink config"
         );
         assert!(
             flagged_lines.contains(&7),
-            "##Introduction SHOULD be flagged in MkDocs flavor"
+            "##Introduction SHOULD be flagged with magiclink config"
         );
     }
 
     #[test]
     fn test_mkdocs_magiclink_fix_exact_output() {
-        // Verify fix() produces exact expected output
-        let rule = MD018NoMissingSpaceAtx::new();
+        // Verify fix() produces exact expected output with magiclink config
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
         let content = "#10 discusses the issue.\n\n#Summary";
-        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Exact expected output: #10 preserved, #Summary fixed
         let expected = "#10 discusses the issue.\n\n# Summary";
         assert_eq!(
             fixed, expected,
-            "MkDocs fix should preserve MagicLink refs and fix non-numeric headings"
+            "magiclink config fix should preserve MagicLink refs and fix non-numeric headings"
         );
     }
 
     #[test]
     fn test_mkdocs_magiclink_edge_cases() {
         // Test various edge cases for MagicLink pattern matching
-        let rule = MD018NoMissingSpaceAtx::new();
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
-        // These should all be SKIPPED in MkDocs flavor (valid MagicLink refs)
+        // These should all be SKIPPED with magiclink config (valid MagicLink refs)
         // Note: #1 alone is skipped due to content length < 2, not MagicLink
         let valid_refs = [
             "#10",             // Two digits
@@ -1087,12 +1142,12 @@ More content.
 
         for ref_str in valid_refs {
             assert!(
-                rule.check_atx_heading_line(ref_str, MarkdownFlavor::MkDocs).is_none(),
-                "{ref_str:?} should be skipped as MagicLink ref in MkDocs flavor"
+                rule.check_atx_heading_line(ref_str, MarkdownFlavor::Standard).is_none(),
+                "{ref_str:?} should be skipped as MagicLink ref with magiclink config"
             );
         }
 
-        // These should still be FLAGGED in MkDocs flavor (not valid MagicLink refs)
+        // These should still be FLAGGED with magiclink config (not valid MagicLink refs)
         let invalid_refs = [
             "#10abc",   // Alphanumeric continuation
             "#10a",     // Single alpha continuation
@@ -1104,8 +1159,8 @@ More content.
 
         for ref_str in invalid_refs {
             assert!(
-                rule.check_atx_heading_line(ref_str, MarkdownFlavor::MkDocs).is_some(),
-                "{ref_str:?} should be flagged in MkDocs flavor (not a valid MagicLink ref)"
+                rule.check_atx_heading_line(ref_str, MarkdownFlavor::Standard).is_some(),
+                "{ref_str:?} should be flagged with magiclink config (not a valid MagicLink ref)"
             );
         }
     }
@@ -1114,31 +1169,31 @@ More content.
     fn test_mkdocs_magiclink_hyphenated_continuation() {
         // Hyphenated patterns like #10-related should still be flagged
         // because they're likely malformed headings, not MagicLink refs
-        let rule = MD018NoMissingSpaceAtx::new();
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
         // Hyphen is not alphanumeric, so #10- would match as MagicLink
         // But #10-related has alphanumeric after the hyphen
         // The regex ^#\d+(?:\s|[^a-zA-Z0-9]|$) would match #10- but not consume -related
         // So #10-related would match (the -r part is after the match)
         assert!(
-            rule.check_atx_heading_line("#10-", MarkdownFlavor::MkDocs).is_none(),
-            "#10- should be skipped (hyphen is non-alphanumeric terminator)"
+            rule.check_atx_heading_line("#10-", MarkdownFlavor::Standard).is_none(),
+            "#10- should be skipped with magiclink config (hyphen is non-alphanumeric terminator)"
         );
     }
 
     #[test]
     fn test_mkdocs_magiclink_standalone_number() {
         // #10 alone on a line (common in changelogs)
-        let rule = MD018NoMissingSpaceAtx::new();
+        let rule = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
 
         let content = "See issue:\n\n#10\n\nFor details.";
-        let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
+        let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
-        // #10 alone should not be flagged in MkDocs flavor
+        // #10 alone should not be flagged with magiclink config
         assert!(
             result.is_empty(),
-            "Standalone #10 should not be flagged in MkDocs flavor"
+            "Standalone #10 should not be flagged with magiclink config"
         );
 
         // Verify fix doesn't modify it
@@ -1170,19 +1225,403 @@ More content.
 
     #[test]
     fn test_mkdocs_vs_standard_fix_comparison() {
-        // Compare fix output between MkDocs and Standard flavors
+        // Compare fix output between magiclink enabled and disabled
+        let content = "#10 is an issue\n#Summary";
+        let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
+
+        // With magiclink: preserves #10, fixes #Summary
+        let rule_magiclink = MD018NoMissingSpaceAtx::from_config_struct(MD018Config { magiclink: true });
+        let fixed_magiclink = rule_magiclink.fix(&ctx).unwrap();
+        assert_eq!(fixed_magiclink, "#10 is an issue\n# Summary");
+
+        // Without magiclink: fixes both
+        let rule_default = MD018NoMissingSpaceAtx::new();
+        let fixed_default = rule_default.fix(&ctx).unwrap();
+        assert_eq!(fixed_default, "# 10 is an issue\n# Summary");
+    }
+
+    // ==================== Obsidian flavor tests ====================
+
+    #[test]
+    fn test_obsidian_tag_skips_simple_tags() {
+        // Obsidian flavor should skip tag syntax (#tagname)
         let rule = MD018NoMissingSpaceAtx::new();
 
-        let content = "#10 is an issue\n#Summary";
+        // Simple tags should be SKIPPED in Obsidian flavor
+        assert!(
+            rule.check_atx_heading_line("#hey", MarkdownFlavor::Obsidian).is_none(),
+            "#hey should be skipped in Obsidian flavor (tag syntax)"
+        );
+        assert!(
+            rule.check_atx_heading_line("#tag", MarkdownFlavor::Obsidian).is_none(),
+            "#tag should be skipped in Obsidian flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#hello", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#hello should be skipped in Obsidian flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#myTag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#myTag should be skipped in Obsidian flavor"
+        );
+    }
 
-        // MkDocs: preserves #10, fixes #Summary
-        let ctx_mkdocs = LintContext::new(content, MarkdownFlavor::MkDocs, None);
-        let fixed_mkdocs = rule.fix(&ctx_mkdocs).unwrap();
-        assert_eq!(fixed_mkdocs, "#10 is an issue\n# Summary");
+    #[test]
+    fn test_obsidian_tag_skips_complex_tags() {
+        // Obsidian tags can have hyphens, underscores, numbers, and slashes
+        let rule = MD018NoMissingSpaceAtx::new();
 
-        // Standard: fixes both
+        // Complex tag patterns should be SKIPPED in Obsidian flavor
+        assert!(
+            rule.check_atx_heading_line("#project/active", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#project/active should be skipped in Obsidian flavor (nested tag)"
+        );
+        assert!(
+            rule.check_atx_heading_line("#my-tag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#my-tag should be skipped in Obsidian flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#my_tag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#my_tag should be skipped in Obsidian flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#tag2023", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#tag2023 should be skipped in Obsidian flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#project/sub/task", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#project/sub/task should be skipped in Obsidian flavor"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_tag_with_trailing_content() {
+        // Tags followed by whitespace should still be skipped
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        assert!(
+            rule.check_atx_heading_line("#hey ", MarkdownFlavor::Obsidian).is_none(),
+            "#hey followed by space should be skipped"
+        );
+        assert!(
+            rule.check_atx_heading_line("#tag some text", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#tag followed by text should be skipped"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_tag_still_flags_multi_hash() {
+        // Obsidian tags only use single #, so ##tag should still be flagged
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        assert!(
+            rule.check_atx_heading_line("##tag", MarkdownFlavor::Obsidian).is_some(),
+            "##tag should be flagged in Obsidian flavor (only single # is a tag)"
+        );
+        assert!(
+            rule.check_atx_heading_line("###hello", MarkdownFlavor::Obsidian)
+                .is_some(),
+            "###hello should be flagged in Obsidian flavor"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_tag_numeric_still_flagged() {
+        // Tags cannot start with a number in Obsidian, so #123 should still be flagged
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        assert!(
+            rule.check_atx_heading_line("#123", MarkdownFlavor::Obsidian).is_some(),
+            "#123 should be flagged in Obsidian flavor (tags cannot start with digit)"
+        );
+        assert!(
+            rule.check_atx_heading_line("#10", MarkdownFlavor::Obsidian).is_some(),
+            "#10 should be flagged in Obsidian flavor"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_flavor_full_check() {
+        // Integration test: verify Obsidian flavor skips tags through full check() flow
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        let content = r#"# Real Heading
+
+#hey this is a tag
+
+#project/active also a tag
+
+##Introduction
+
+#123
+"#;
+
+        // Obsidian flavor - should skip #hey and #project/active, but flag ##Introduction and #123
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+
+        let flagged_lines: Vec<usize> = result.iter().map(|w| w.line).collect();
+        assert!(
+            !flagged_lines.contains(&3),
+            "#hey should NOT be flagged in Obsidian flavor"
+        );
+        assert!(
+            !flagged_lines.contains(&5),
+            "#project/active should NOT be flagged in Obsidian flavor"
+        );
+        assert!(
+            flagged_lines.contains(&7),
+            "##Introduction SHOULD be flagged in Obsidian flavor"
+        );
+        assert!(flagged_lines.contains(&9), "#123 SHOULD be flagged in Obsidian flavor");
+    }
+
+    #[test]
+    fn test_obsidian_flavor_fix_exact_output() {
+        // Verify fix() produces exact expected output
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // In Obsidian flavor, all single-# patterns that look like tags are preserved
+        // Only multi-hash patterns (##tag) and numeric patterns (#123) are fixed
+        let content = "#hey is a tag.\n\n##Introduction";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Exact expected output: #hey preserved, ##Introduction fixed
+        let expected = "#hey is a tag.\n\n## Introduction";
+        assert_eq!(
+            fixed, expected,
+            "Obsidian fix should preserve tags and fix multi-hash headings"
+        );
+    }
+
+    #[test]
+    fn test_standard_flavor_flags_obsidian_tags() {
+        // Standard flavor should flag patterns that look like Obsidian tags
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        assert!(
+            rule.check_atx_heading_line("#hey", MarkdownFlavor::Standard).is_some(),
+            "#hey should be flagged in Standard flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#tag", MarkdownFlavor::Standard).is_some(),
+            "#tag should be flagged in Standard flavor"
+        );
+        assert!(
+            rule.check_atx_heading_line("#project/active", MarkdownFlavor::Standard)
+                .is_some(),
+            "#project/active should be flagged in Standard flavor"
+        );
+    }
+
+    #[test]
+    fn test_obsidian_vs_standard_fix_comparison() {
+        // Compare fix output between Obsidian and Standard flavors
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Use a pattern that clearly shows the difference:
+        // - #hey tag: single-hash, looks like Obsidian tag followed by text
+        // - ##Introduction: multi-hash, clearly a malformed heading
+        let content = "#hey tag\n##Introduction";
+
+        // Obsidian: preserves #hey tag (single-hash tag syntax), fixes ##Introduction
+        let ctx_obsidian = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let fixed_obsidian = rule.fix(&ctx_obsidian).unwrap();
+        assert_eq!(fixed_obsidian, "#hey tag\n## Introduction");
+
+        // Standard: fixes both (no tag awareness)
         let ctx_standard = LintContext::new(content, MarkdownFlavor::Standard, None);
         let fixed_standard = rule.fix(&ctx_standard).unwrap();
-        assert_eq!(fixed_standard, "# 10 is an issue\n# Summary");
+        assert_eq!(fixed_standard, "# hey tag\n## Introduction");
+    }
+
+    #[test]
+    fn test_obsidian_tag_edge_cases() {
+        // Test various edge cases for Obsidian tag pattern matching
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Valid Obsidian tags - should be SKIPPED
+        let valid_tags = [
+            "#a",      // Minimum valid tag (but note: may be skipped due to length < 2)
+            "#tag",    // Simple tag
+            "#Tag",    // Capitalized tag
+            "#TAG",    // Uppercase tag
+            "#my-tag", // Hyphenated tag
+            "#my_tag", // Underscored tag
+            "#tag123", // Tag with trailing numbers
+            "#a1",     // Short tag with number
+            "#日本語", // Unicode tag
+            "#über",   // Unicode with umlaut
+        ];
+
+        for tag in valid_tags {
+            // Note: #a and #a1 might be skipped due to content length < 2 rule
+            let result = rule.check_atx_heading_line(tag, MarkdownFlavor::Obsidian);
+            // We don't assert is_none because some might be skipped by other rules
+            // Just verify the pattern doesn't cause errors
+            let _ = result;
+        }
+
+        // Invalid tags (start with digit) - should be FLAGGED
+        let invalid_tags = ["#1tag", "#123", "#2023-project"];
+
+        for tag in invalid_tags {
+            assert!(
+                rule.check_atx_heading_line(tag, MarkdownFlavor::Obsidian).is_some(),
+                "{tag:?} should be flagged in Obsidian flavor (starts with digit)"
+            );
+        }
+    }
+
+    #[test]
+    fn test_obsidian_tag_alone_on_line() {
+        // Standalone tag on a line (common in Obsidian notes)
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        let content = "Some text\n\n#todo\n\nMore text.";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+
+        // #todo alone should not be flagged in Obsidian flavor
+        assert!(
+            result.is_empty(),
+            "Standalone #todo should not be flagged in Obsidian flavor"
+        );
+
+        // Verify fix doesn't modify it
+        let fixed = rule.fix(&ctx).unwrap();
+        assert_eq!(fixed, content, "fix() should not modify standalone Obsidian tag");
+    }
+
+    #[test]
+    fn test_obsidian_deeply_nested_tags() {
+        // Obsidian supports deeply nested tags with /
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        let nested_tags = [
+            "#a/b",
+            "#a/b/c",
+            "#project/2023/q1/task",
+            "#work/meetings/weekly",
+            "#life/health/exercise/running",
+        ];
+
+        for tag in nested_tags {
+            assert!(
+                rule.check_atx_heading_line(tag, MarkdownFlavor::Obsidian).is_none(),
+                "{tag:?} should be skipped in Obsidian flavor (nested tag)"
+            );
+        }
+    }
+
+    #[test]
+    fn test_obsidian_unicode_tags() {
+        // Obsidian supports Unicode in tags
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        let unicode_tags = [
+            "#日本語", // Japanese
+            "#中文",   // Chinese
+            "#한국어", // Korean
+            "#über",   // German umlaut
+            "#café",   // French accent
+            "#ñoño",   // Spanish tilde
+            "#Москва", // Russian
+            "#αβγ",    // Greek
+        ];
+
+        for tag in unicode_tags {
+            assert!(
+                rule.check_atx_heading_line(tag, MarkdownFlavor::Obsidian).is_none(),
+                "{tag:?} should be skipped in Obsidian flavor (Unicode tag)"
+            );
+        }
+    }
+
+    #[test]
+    fn test_obsidian_tags_with_special_endings() {
+        // Tags followed by various punctuation
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Tags followed by space then text should be skipped
+        assert!(
+            rule.check_atx_heading_line("#tag followed by text", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#tag followed by text should be skipped"
+        );
+
+        // Tag at end of line (no trailing space)
+        let content = "#todo";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "#todo at end of line should be skipped");
+    }
+
+    #[test]
+    fn test_obsidian_combined_with_other_skip_contexts() {
+        // Verify Obsidian tags in code blocks and HTML comments are still skipped
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Tag inside code block (should be skipped by code block logic, not Obsidian logic)
+        let content = "```\n#todo\n```";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Tag in code block should be skipped");
+
+        // Tag inside HTML comment
+        let content = "<!-- #todo -->";
+        let ctx = LintContext::new(content, MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Tag in HTML comment should be skipped");
+    }
+
+    #[test]
+    fn test_obsidian_boundary_cases() {
+        // Test boundary cases for Obsidian tag detection
+        let rule = MD018NoMissingSpaceAtx::new();
+
+        // Minimum valid tag (single char after #)
+        // Note: #a alone might be skipped by content length < 2 rule
+        // #ab should definitely be recognized as a tag
+        assert!(
+            rule.check_atx_heading_line("#ab", MarkdownFlavor::Obsidian).is_none(),
+            "#ab should be skipped in Obsidian flavor"
+        );
+
+        // Tag with underscore
+        assert!(
+            rule.check_atx_heading_line("#my_tag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#my_tag should be skipped"
+        );
+
+        // Tag with hyphen
+        assert!(
+            rule.check_atx_heading_line("#my-tag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#my-tag should be skipped"
+        );
+
+        // Tag with mixed case
+        assert!(
+            rule.check_atx_heading_line("#MyTag", MarkdownFlavor::Obsidian)
+                .is_none(),
+            "#MyTag should be skipped"
+        );
+
+        // All caps (could be a tag or acronym)
+        assert!(
+            rule.check_atx_heading_line("#TODO", MarkdownFlavor::Obsidian).is_none(),
+            "#TODO should be skipped in Obsidian flavor"
+        );
     }
 }
