@@ -30,6 +30,9 @@ static MALFORMED_BLOCKQUOTE_PATTERNS: LazyLock<Vec<(Regex, &'static str)>> = Laz
     ]
 });
 
+// Cached regex for blockquote validation
+static BLOCKQUOTE_PATTERN: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"^\s*>").unwrap());
+
 /// Rule MD027: No multiple spaces after blockquote symbol
 ///
 /// See [docs/md027.md](../../docs/md027.md) for full documentation, configuration, and examples.
@@ -52,15 +55,20 @@ impl Rule for MD027MultipleSpacesBlockquote {
         for (line_idx, line_info) in ctx.lines.iter().enumerate() {
             let line_num = line_idx + 1;
 
-            // Skip lines in code blocks
-            if line_info.in_code_block {
+            // Skip lines in code blocks and HTML blocks
+            if line_info.in_code_block || line_info.in_html_block {
                 continue;
             }
 
             // Check if this line is a blockquote using cached info
             if let Some(blockquote) = &line_info.blockquote {
                 // Part 1: Check for multiple spaces after the blockquote marker
-                if blockquote.has_multiple_spaces_after_marker {
+                // Skip if line is in a list block - extra spaces may be list continuation indent
+                // Also skip if previous line in same blockquote context had a list item
+                // (covers cases where list block detection doesn't catch all continuation lines)
+                let is_likely_list_continuation =
+                    ctx.is_in_list_block(line_num) || self.previous_blockquote_line_had_list(ctx, line_idx);
+                if blockquote.has_multiple_spaces_after_marker && !is_likely_list_continuation {
                     // Find where the extra spaces start in the line
                     // We need to find the position after the markers and first space/tab
                     let mut byte_pos = 0;
@@ -145,10 +153,14 @@ impl Rule for MD027MultipleSpacesBlockquote {
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let mut result = Vec::with_capacity(ctx.lines.len());
 
-        for line_info in &ctx.lines {
+        for (line_idx, line_info) in ctx.lines.iter().enumerate() {
+            let line_num = line_idx + 1;
             if let Some(blockquote) = &line_info.blockquote {
                 // Fix blockquotes with multiple spaces after the marker
-                if blockquote.has_multiple_spaces_after_marker {
+                // Skip if line is in a list block - extra spaces are list continuation indent
+                let is_likely_list_continuation =
+                    ctx.is_in_list_block(line_num) || self.previous_blockquote_line_had_list(ctx, line_idx);
+                if blockquote.has_multiple_spaces_after_marker && !is_likely_list_continuation {
                     // Rebuild the line with exactly one space after the markers
                     // But don't add a space if the content is empty to avoid MD009 conflicts
                     let fixed_line = if blockquote.content.is_empty() {
@@ -200,6 +212,33 @@ impl Rule for MD027MultipleSpacesBlockquote {
 }
 
 impl MD027MultipleSpacesBlockquote {
+    /// Check if a previous line in the same blockquote context had a list item
+    /// This helps identify list continuation lines even when list block detection
+    /// doesn't catch all continuation lines
+    fn previous_blockquote_line_had_list(&self, ctx: &crate::lint_context::LintContext, line_idx: usize) -> bool {
+        // Look backwards for a blockquote line with a list item
+        // Stop when we hit a non-blockquote line or find a list item
+        for prev_idx in (0..line_idx).rev() {
+            let prev_line = &ctx.lines[prev_idx];
+
+            // If previous line is not a blockquote, stop searching
+            if prev_line.blockquote.is_none() {
+                return false;
+            }
+
+            // If previous line has a list item, this could be list continuation
+            if prev_line.list_item.is_some() {
+                return true;
+            }
+
+            // If it's in a list block, that's also good enough
+            if ctx.is_in_list_block(prev_idx + 1) {
+                return true;
+            }
+        }
+        false
+    }
+
     /// Detect malformed blockquote attempts where user intent is clear
     fn detect_malformed_blockquote_attempts(&self, line: &str) -> Vec<(usize, usize, String, String)> {
         let mut results = Vec::new();
@@ -297,8 +336,7 @@ impl MD027MultipleSpacesBlockquote {
 
         // 4. Fixed version should actually be a valid blockquote
         // Check if it starts with optional whitespace followed by >
-        let blockquote_pattern = regex::Regex::new(r"^\s*>").unwrap();
-        if !blockquote_pattern.is_match(fixed) {
+        if !BLOCKQUOTE_PATTERN.is_match(fixed) {
             return false;
         }
 
@@ -334,7 +372,7 @@ mod tests {
     fn test_valid_blockquote() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = "> This is a blockquote\n> > Nested quote";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Valid blockquotes should not be flagged");
     }
@@ -343,7 +381,7 @@ mod tests {
     fn test_multiple_spaces_after_marker() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">  This has two spaces\n>   This has three spaces";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 1);
@@ -358,7 +396,7 @@ mod tests {
         let rule = MD027MultipleSpacesBlockquote;
         // LintContext sees these as single-level blockquotes because of the space between markers
         let content = ">  Two spaces after marker\n>>  Two spaces in nested blockquote";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert!(result[0].message.contains("Multiple spaces"));
@@ -371,7 +409,7 @@ mod tests {
         // LintContext sees >>text as a valid nested blockquote with no space after marker
         // MD027 doesn't flag this as malformed, only as missing space after marker
         let content = ">>This is a nested blockquote without space after markers";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // This should not be flagged at all since >>text is valid CommonMark
         assert_eq!(result.len(), 0);
@@ -382,7 +420,7 @@ mod tests {
         let rule = MD027MultipleSpacesBlockquote;
         // LintContext sees >>>text as a valid triple-nested blockquote
         let content = ">>>This is deeply nested without spaces after markers";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // This should not be flagged - >>>text is valid CommonMark
         assert_eq!(result.len(), 0);
@@ -394,7 +432,7 @@ mod tests {
         // "> >text" is parsed as single-level blockquote with ">text" as content
         // This is valid CommonMark and not detected as malformed
         let content = "> >This looks like nested but is actually single level with >This as content";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 0);
     }
@@ -404,7 +442,7 @@ mod tests {
         let rule = MD027MultipleSpacesBlockquote;
         // 4+ spaces makes this a code block, not a blockquote
         let content = "   >This has 3 spaces indent and no space after marker";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // LintContext sees this as a blockquote with no space after marker
         // MD027 doesn't flag this as malformed
@@ -415,7 +453,7 @@ mod tests {
     fn test_fix_multiple_spaces() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">  Two spaces\n>   Three spaces";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "> Two spaces\n> Three spaces");
     }
@@ -425,7 +463,7 @@ mod tests {
         let rule = MD027MultipleSpacesBlockquote;
         // These are valid nested blockquotes, not malformed
         let content = ">>Nested without spaces\n>>>Deeply nested without spaces";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         // No fix needed - these are valid
         assert_eq!(fixed, content);
@@ -436,7 +474,7 @@ mod tests {
         let rule = MD027MultipleSpacesBlockquote;
         // This is valid - single blockquote with >Extra as content
         let content = "> >Extra marker here";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         // No fix needed
         assert_eq!(fixed, content);
@@ -446,7 +484,7 @@ mod tests {
     fn test_code_block_ignored() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = "```\n>  This is in a code block\n```";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Code blocks should be ignored");
     }
@@ -455,7 +493,7 @@ mod tests {
     fn test_short_content_not_flagged() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">>>\n>>";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Very short content should not be flagged");
     }
@@ -464,7 +502,7 @@ mod tests {
     fn test_non_prose_not_flagged() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">>#header\n>>[link]\n>>`code`\n>>http://example.com";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Non-prose content should not be flagged");
     }
@@ -473,12 +511,12 @@ mod tests {
     fn test_preserve_trailing_newline() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">  Two spaces\n";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "> Two spaces\n");
 
         let content_no_newline = ">  Two spaces";
-        let ctx2 = LintContext::new(content_no_newline, crate::config::MarkdownFlavor::Standard);
+        let ctx2 = LintContext::new(content_no_newline, crate::config::MarkdownFlavor::Standard, None);
         let fixed2 = rule.fix(&ctx2).unwrap();
         assert_eq!(fixed2, "> Two spaces");
     }
@@ -487,7 +525,7 @@ mod tests {
     fn test_mixed_issues() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">  Multiple spaces here\n>>Normal nested quote\n> Normal quote";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Should only flag the multiple spaces");
         assert_eq!(result[0].line, 1);
@@ -530,7 +568,7 @@ mod tests {
     fn test_empty_blockquote() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = ">\n>  \n> content";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         // Empty blockquotes with multiple spaces should still be flagged
         assert_eq!(result.len(), 1);
@@ -541,65 +579,111 @@ mod tests {
     fn test_fix_preserves_indentation() {
         let rule = MD027MultipleSpacesBlockquote;
         let content = "  >  Indented with multiple spaces";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "  > Indented with multiple spaces");
     }
 
     #[test]
-    fn test_tabs_after_marker() {
+    fn test_tabs_after_marker_not_flagged() {
+        // MD027 only flags multiple SPACES, not tabs
+        // Tabs after blockquote markers are handled by MD010 (no-hard-tabs)
+        // This matches markdownlint reference behavior
         let rule = MD027MultipleSpacesBlockquote;
-        // Tab after marker - should be flagged as multiple spaces
+
+        // Tab after marker - NOT flagged by MD027 (that's MD010's job)
         let content = ">\tTab after marker";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Tab after marker should be flagged");
-        assert_eq!(result[0].message, "Multiple spaces after quote marker (>)");
+        assert_eq!(result.len(), 0, "Single tab should not be flagged by MD027");
 
-        // Tab and space after marker
-        let content2 = ">\t Space then tab";
-        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
+        // Two tabs after marker - NOT flagged by MD027
+        let content2 = ">\t\tTwo tabs";
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard, None);
         let result2 = rule.check(&ctx2).unwrap();
-        assert_eq!(result2.len(), 1, "Tab and space should be flagged");
-
-        // Two tabs after marker
-        let content3 = ">\t\tTwo tabs";
-        let ctx3 = LintContext::new(content3, crate::config::MarkdownFlavor::Standard);
-        let result3 = rule.check(&ctx3).unwrap();
-        assert_eq!(result3.len(), 1, "Two tabs should be flagged");
+        assert_eq!(result2.len(), 0, "Tabs should not be flagged by MD027");
     }
 
     #[test]
     fn test_mixed_spaces_and_tabs() {
         let rule = MD027MultipleSpacesBlockquote;
-        // Space then tab
-        let content = "> \tSpace then tab";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        // Space then tab - only flags if there are multiple spaces
+        // The tab itself is MD010's domain
+        let content = ">  Space Space";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
-        assert_eq!(result[0].column, 3); // Points to the tab
+        assert_eq!(result[0].column, 3); // Points to the extra space
 
-        // Tab then space
-        let content2 = ">\t Tab then space";
-        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
+        // Three spaces should be flagged
+        let content2 = ">   Three spaces";
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard, None);
         let result2 = rule.check(&ctx2).unwrap();
         assert_eq!(result2.len(), 1);
-        assert_eq!(result2[0].column, 3); // Points to the space after tab
     }
 
     #[test]
-    fn test_fix_tabs() {
+    fn test_fix_multiple_spaces_various() {
         let rule = MD027MultipleSpacesBlockquote;
-        // Fix should remove extra tabs
-        let content = ">\t\tTwo tabs";
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        // Fix should remove extra spaces
+        let content = ">   Three spaces";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "> Two tabs");
+        assert_eq!(fixed, "> Three spaces");
 
-        // Fix mixed spaces and tabs
-        let content2 = "> \t Mixed";
-        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
+        // Fix multiple spaces
+        let content2 = ">    Four spaces";
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard, None);
         let fixed2 = rule.fix(&ctx2).unwrap();
-        assert_eq!(fixed2, "> Mixed");
+        assert_eq!(fixed2, "> Four spaces");
+    }
+
+    #[test]
+    fn test_list_continuation_inside_blockquote_not_flagged() {
+        // List continuation indentation inside blockquotes should NOT be flagged
+        // This matches markdownlint-cli behavior
+        let rule = MD027MultipleSpacesBlockquote;
+
+        // List with continuation inside blockquote
+        let content = "> - Item starts here\n>   This continues the item\n> - Another item";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "List continuation inside blockquote should not be flagged, got: {result:?}"
+        );
+
+        // Multiple list items with continuations
+        let content2 = "> * First item\n>   First item continuation\n>   Still continuing\n> * Second item";
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard, None);
+        let result2 = rule.check(&ctx2).unwrap();
+        assert!(
+            result2.is_empty(),
+            "List continuations should not be flagged, got: {result2:?}"
+        );
+    }
+
+    #[test]
+    fn test_list_continuation_fix_preserves_indentation() {
+        // Ensure fix doesn't break list continuation indentation
+        let rule = MD027MultipleSpacesBlockquote;
+
+        let content = "> - Item\n>   continuation";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+        // Should preserve the list continuation indentation
+        assert_eq!(fixed, "> - Item\n>   continuation");
+    }
+
+    #[test]
+    fn test_non_list_multiple_spaces_still_flagged() {
+        // Non-list lines with multiple spaces should still be flagged
+        let rule = MD027MultipleSpacesBlockquote;
+
+        // Just extra spaces, not a list
+        let content = ">  This has extra spaces";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Non-list line should be flagged");
     }
 }
