@@ -66,16 +66,20 @@ impl Rule for MD030ListMarkerSpace {
             return Ok(warnings);
         }
 
-        // Collect lines once
-        let lines: Vec<&str> = ctx.content.lines().collect();
+        let lines = ctx.raw_lines();
 
         // Track which lines we've already processed (to avoid duplicates)
         let mut processed_lines = std::collections::HashSet::new();
 
         // First pass: Check parser-recognized list items
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
-            // Skip code blocks and math blocks - content inside these is not markdown
-            if line_info.list_item.is_some() && !line_info.in_code_block && !line_info.in_math_block {
+            // Skip code blocks, math blocks, PyMdown blocks, and MkDocs markdown HTML divs (grid cards use custom spacing)
+            if line_info.list_item.is_some()
+                && !line_info.in_code_block
+                && !line_info.in_math_block
+                && !line_info.in_pymdown_block
+                && !line_info.in_mkdocs_html_markdown
+            {
                 let line_num_1based = line_num + 1;
                 processed_lines.insert(line_num_1based);
 
@@ -105,7 +109,7 @@ impl Rule for MD030ListMarkerSpace {
                     let actual_spaces = list_info.content_column.saturating_sub(marker_end);
 
                     // Determine if this is a multi-line list item
-                    let is_multi_line = self.is_multi_line_list_item(ctx, line_num_1based, &lines);
+                    let is_multi_line = self.is_multi_line_list_item(ctx, line_num_1based, lines);
                     let expected_spaces = self.get_expected_spaces(list_type, is_multi_line);
 
                     if actual_spaces != expected_spaces {
@@ -156,18 +160,20 @@ impl Rule for MD030ListMarkerSpace {
                 && (line_info.in_code_block
                     || line_info.in_front_matter
                     || line_info.in_html_comment
-                    || line_info.in_math_block)
+                    || line_info.in_math_block
+                    || line_info.in_pymdown_block
+                    || line_info.in_mkdocs_html_markdown)
             {
                 continue;
             }
 
             // Skip indented code blocks
-            if self.is_indented_code_block(line, line_idx, &lines) {
+            if self.is_indented_code_block(line, line_idx, lines) {
                 continue;
             }
 
             // Try to detect list-like patterns using regex-based detection
-            if let Some(warning) = self.check_unrecognized_list_marker(ctx, line, line_num, &lines) {
+            if let Some(warning) = self.check_unrecognized_list_marker(ctx, line, line_num, lines) {
                 warnings.push(warning);
             }
         }
@@ -225,7 +231,7 @@ impl Rule for MD030ListMarkerSpace {
             return Ok(content.to_string());
         }
 
-        let lines: Vec<&str> = content.lines().collect();
+        let lines = ctx.raw_lines();
         let mut result_lines = Vec::with_capacity(lines.len());
 
         for (line_idx, line) in lines.iter().enumerate() {
@@ -240,7 +246,7 @@ impl Rule for MD030ListMarkerSpace {
             }
 
             // Skip if this is an indented code block (4+ spaces with blank line before)
-            if self.is_indented_code_block(line, line_idx, &lines) {
+            if self.is_indented_code_block(line, line_idx, lines) {
                 result_lines.push(line.to_string());
                 continue;
             }
@@ -249,7 +255,7 @@ impl Rule for MD030ListMarkerSpace {
             // This ensures we fix spacing on ALL lines that look like list items,
             // even if the parser doesn't recognize them due to strict nesting rules.
             // User intention matters: if it looks like a list item, fix it.
-            let is_multi_line = self.is_multi_line_list_item(ctx, line_num, &lines);
+            let is_multi_line = self.is_multi_line_list_item(ctx, line_num, lines);
             if let Some(fixed_line) = self.try_fix_list_marker_spacing_with_context(line, is_multi_line) {
                 result_lines.push(fixed_line);
             } else {
