@@ -453,17 +453,269 @@ impl MD033NoInlineHtml {
     }
 
     /// Convert self-closing HTML tags to their Markdown equivalents.
-    fn convert_self_closing_to_markdown(&self, tag_name: &str) -> Option<String> {
+    fn convert_self_closing_to_markdown(&self, tag_name: &str, opening_tag: &str) -> Option<String> {
         match tag_name {
             "br" => match self.config.br_style {
                 md033_config::BrStyle::TrailingSpaces => Some("  \n".to_string()),
                 md033_config::BrStyle::Backslash => Some("\\\n".to_string()),
             },
             "hr" => Some("\n---\n".to_string()),
+            "img" => Self::convert_img_to_markdown(opening_tag),
             _ => None,
         }
     }
 
+    /// Parse all attributes from an HTML tag into a list of (name, value) pairs.
+    /// This provides proper attribute parsing instead of naive string matching.
+    fn parse_attributes(tag: &str) -> Vec<(String, Option<String>)> {
+        let mut attrs = Vec::new();
+
+        // Remove < and > and tag name
+        let tag_content = tag.trim_start_matches('<').trim_end_matches('>').trim_end_matches('/');
+
+        // Find first whitespace to skip tag name
+        let attr_start = tag_content
+            .find(|c: char| c.is_whitespace())
+            .map(|i| i + 1)
+            .unwrap_or(tag_content.len());
+
+        if attr_start >= tag_content.len() {
+            return attrs;
+        }
+
+        let attr_str = &tag_content[attr_start..];
+        let mut chars = attr_str.chars().peekable();
+
+        while chars.peek().is_some() {
+            // Skip whitespace
+            while chars.peek().is_some_and(|c| c.is_whitespace()) {
+                chars.next();
+            }
+
+            if chars.peek().is_none() {
+                break;
+            }
+
+            // Read attribute name
+            let mut attr_name = String::new();
+            while let Some(&c) = chars.peek() {
+                if c.is_whitespace() || c == '=' || c == '>' || c == '/' {
+                    break;
+                }
+                attr_name.push(c);
+                chars.next();
+            }
+
+            if attr_name.is_empty() {
+                break;
+            }
+
+            // Skip whitespace before =
+            while chars.peek().is_some_and(|c| c.is_whitespace()) {
+                chars.next();
+            }
+
+            // Check for = and value
+            if chars.peek() == Some(&'=') {
+                chars.next(); // consume =
+
+                // Skip whitespace after =
+                while chars.peek().is_some_and(|c| c.is_whitespace()) {
+                    chars.next();
+                }
+
+                // Read value
+                let mut value = String::new();
+                if let Some(&quote) = chars.peek() {
+                    if quote == '"' || quote == '\'' {
+                        chars.next(); // consume opening quote
+                        for c in chars.by_ref() {
+                            if c == quote {
+                                break;
+                            }
+                            value.push(c);
+                        }
+                    } else {
+                        // Unquoted value
+                        while let Some(&c) = chars.peek() {
+                            if c.is_whitespace() || c == '>' || c == '/' {
+                                break;
+                            }
+                            value.push(c);
+                            chars.next();
+                        }
+                    }
+                }
+                attrs.push((attr_name.to_ascii_lowercase(), Some(value)));
+            } else {
+                // Boolean attribute (no value)
+                attrs.push((attr_name.to_ascii_lowercase(), None));
+            }
+        }
+
+        attrs
+    }
+
+    /// Extract an HTML attribute value from a tag string.
+    /// Handles double quotes, single quotes, and unquoted values.
+    /// Returns None if the attribute is not found.
+    fn extract_attribute(tag: &str, attr_name: &str) -> Option<String> {
+        let attrs = Self::parse_attributes(tag);
+        let attr_lower = attr_name.to_ascii_lowercase();
+
+        attrs
+            .into_iter()
+            .find(|(name, _)| name == &attr_lower)
+            .and_then(|(_, value)| value)
+    }
+
+    /// Check if an HTML tag has extra attributes beyond the specified allowed ones.
+    /// Uses proper attribute parsing to avoid false positives from string matching.
+    fn has_extra_attributes(tag: &str, allowed_attrs: &[&str]) -> bool {
+        let attrs = Self::parse_attributes(tag);
+
+        // All event handlers (on*) are dangerous
+        // Plus common attributes that would be lost in markdown conversion
+        const DANGEROUS_ATTR_PREFIXES: &[&str] = &["on"]; // onclick, onload, onerror, etc.
+        const DANGEROUS_ATTRS: &[&str] = &[
+            "class",
+            "id",
+            "style",
+            "target",
+            "rel",
+            "download",
+            "referrerpolicy",
+            "crossorigin",
+            "loading",
+            "decoding",
+            "fetchpriority",
+            "sizes",
+            "srcset",
+            "usemap",
+            "ismap",
+            "width",
+            "height",
+            "name",   // anchor names
+            "data-*", // data attributes (checked separately)
+        ];
+
+        for (attr_name, _) in attrs {
+            // Skip allowed attributes
+            if allowed_attrs.iter().any(|a| a.to_ascii_lowercase() == attr_name) {
+                continue;
+            }
+
+            // Check for event handlers (on*)
+            for prefix in DANGEROUS_ATTR_PREFIXES {
+                if attr_name.starts_with(prefix) && attr_name.len() > prefix.len() {
+                    return true;
+                }
+            }
+
+            // Check for data-* attributes
+            if attr_name.starts_with("data-") {
+                return true;
+            }
+
+            // Check for other dangerous attributes
+            if DANGEROUS_ATTRS.contains(&attr_name.as_str()) {
+                return true;
+            }
+        }
+
+        false
+    }
+
+    /// Convert `<a href="url">text</a>` to `[text](url)` or `[text](url "title")`
+    /// Returns None if conversion is not safe.
+    fn convert_a_to_markdown(opening_tag: &str, inner_content: &str) -> Option<String> {
+        // Extract href attribute
+        let href = Self::extract_attribute(opening_tag, "href")?;
+
+        // Check URL is safe
+        if !MD033Config::is_safe_url(&href) {
+            return None;
+        }
+
+        // Check for nested HTML tags in content
+        if inner_content.contains('<') {
+            return None;
+        }
+
+        // Check for HTML entities that wouldn't render correctly in markdown
+        if inner_content.contains('&') && inner_content.contains(';') {
+            let has_entity = inner_content
+                .split('&')
+                .skip(1)
+                .any(|part| part.split(';').next().is_some_and(|e| !e.is_empty() && e.len() < 10));
+            if has_entity {
+                return None;
+            }
+        }
+
+        // Extract optional title attribute
+        let title = Self::extract_attribute(opening_tag, "title");
+
+        // Check for extra dangerous attributes (title is allowed)
+        if Self::has_extra_attributes(opening_tag, &["href", "title"]) {
+            return None;
+        }
+
+        // Escape special markdown characters in link text
+        // Brackets need escaping to avoid breaking the link syntax
+        let escaped_text = inner_content.replace('[', r"\[").replace(']', r"\]");
+
+        // Escape parentheses in URL
+        let escaped_url = href.replace('(', "%28").replace(')', "%29");
+
+        // Format with or without title
+        if let Some(title_text) = title {
+            // Escape quotes in title
+            let escaped_title = title_text.replace('"', r#"\""#);
+            Some(format!("[{escaped_text}]({escaped_url} \"{escaped_title}\")"))
+        } else {
+            Some(format!("[{escaped_text}]({escaped_url})"))
+        }
+    }
+
+    /// Convert `<img src="url" alt="text">` to `![alt](src)` or `![alt](src "title")`
+    /// Returns None if conversion is not safe.
+    fn convert_img_to_markdown(tag: &str) -> Option<String> {
+        // Extract src attribute (required)
+        let src = Self::extract_attribute(tag, "src")?;
+
+        // Check URL is safe
+        if !MD033Config::is_safe_url(&src) {
+            return None;
+        }
+
+        // Extract alt attribute (optional, default to empty)
+        let alt = Self::extract_attribute(tag, "alt").unwrap_or_default();
+
+        // Extract optional title attribute
+        let title = Self::extract_attribute(tag, "title");
+
+        // Check for extra dangerous attributes (title is allowed)
+        if Self::has_extra_attributes(tag, &["src", "alt", "title"]) {
+            return None;
+        }
+
+        // Escape special markdown characters in alt text
+        let escaped_alt = alt.replace('[', r"\[").replace(']', r"\]");
+
+        // Escape parentheses in URL
+        let escaped_url = src.replace('(', "%28").replace(')', "%29");
+
+        // Format with or without title
+        if let Some(title_text) = title {
+            // Escape quotes in title
+            let escaped_title = title_text.replace('"', r#"\""#);
+            Some(format!("![{escaped_alt}]({escaped_url} \"{escaped_title}\")"))
+        } else {
+            Some(format!("![{escaped_alt}]({escaped_url})"))
+        }
+    }
+
     /// Check if an HTML tag has attributes that would make conversion unsafe
     fn has_significant_attributes(opening_tag: &str) -> bool {
         // Tags with just whitespace or empty are fine
@@ -540,12 +792,13 @@ impl MD033NoInlineHtml {
             if self.config.fix
                 && MD033Config::is_safe_fixable_tag(&tag_name)
                 && !in_html_block
-                && let Some(markdown) = self.convert_self_closing_to_markdown(&tag_name)
+                && let Some(markdown) = self.convert_self_closing_to_markdown(&tag_name, opening_tag)
             {
                 return Some((tag_byte_start..tag_byte_start + opening_tag.len(), markdown));
             }
-            // Otherwise just remove the tag
-            return Some((tag_byte_start..tag_byte_start + opening_tag.len(), String::new()));
+            // Can't convert this self-closing tag to Markdown, don't provide a fix
+            // (e.g., <input>, <meta> - these have no Markdown equivalent without the new img support)
+            return None;
         }
 
         // Search for the closing tag after the opening tag (case-insensitive)
@@ -578,8 +831,17 @@ impl MD033NoInlineHtml {
             }
 
             // When fix is enabled and tag is safe to convert, try markdown conversion
-            // Tags with attributes are NOT converted - leave them as-is
             if self.config.fix && MD033Config::is_safe_fixable_tag(&tag_name) {
+                // Handle <a> tags specially - they require attribute extraction
+                if tag_name == "a" {
+                    if let Some(markdown) = Self::convert_a_to_markdown(opening_tag, inner_content) {
+                        return Some((tag_byte_start..closing_byte_end, markdown));
+                    }
+                    // convert_a_to_markdown returned None - unsafe URL, nested HTML, etc.
+                    return None;
+                }
+
+                // For simple tags (em, strong, code, etc.) - no attributes allowed
                 if Self::has_significant_attributes(opening_tag) {
                     // Don't provide a fix for tags with attributes
                     // User may want to keep the attributes, so leave as-is
@@ -593,12 +855,13 @@ impl MD033NoInlineHtml {
                 return None;
             }
 
-            // For non-fixable tags, extract content (removing tags)
-            return Some((tag_byte_start..closing_byte_end, inner_content.to_string()));
+            // For non-fixable tags, don't provide a fix
+            // (e.g., <div>content</div>, <span>text</span>)
+            return None;
         }
 
-        // If no closing tag found, just remove the opening tag
-        Some((tag_byte_start..tag_byte_start + opening_tag.len(), String::new()))
+        // If no closing tag found, don't provide a fix (malformed HTML)
+        None
     }
 }
 
@@ -625,7 +888,7 @@ impl Rule for MD033NoInlineHtml {
         }
 
         let mut warnings = Vec::new();
-        let lines: Vec<&str> = content.lines().collect();
+        let lines = ctx.raw_lines();
 
         // Track nomarkdown and comment blocks (Kramdown extension)
         let mut in_nomarkdown = false;
@@ -671,8 +934,11 @@ impl Rule for MD033NoInlineHtml {
             // Reconstruct tag string from byte offsets
             let tag = &content[html_tag.byte_offset..html_tag.byte_end];
 
-            // Skip tags in code blocks (uses proper code block detection from LintContext)
-            if ctx.line_info(line_num).is_some_and(|info| info.in_code_block) {
+            // Skip tags in code blocks or PyMdown blocks (uses proper detection from LintContext)
+            if ctx
+                .line_info(line_num)
+                .is_some_and(|info| info.in_code_block || info.in_pymdown_block)
+            {
                 continue;
             }
 
@@ -1029,18 +1295,19 @@ mod tests {
 
     #[test]
     fn test_md033_quick_fix_inline_tag() {
-        // Test Quick Fix for inline HTML tags - keeps content, removes tags
+        // Test that non-fixable tags (like <span>) do NOT get a fix
+        // Only safe fixable tags (em, i, strong, b, code, br, hr) with fix=true get fixes
         let rule = MD033NoInlineHtml::default();
         let content = "This has <span>inline text</span> that should keep content.";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1, "Should find one HTML tag");
-        assert!(result[0].fix.is_some(), "Should have a fix");
-
-        let fix = result[0].fix.as_ref().unwrap();
-        assert_eq!(&content[fix.range.clone()], "<span>inline text</span>");
-        assert_eq!(fix.replacement, "inline text");
+        // <span> is NOT a safe fixable tag, so no fix should be provided
+        assert!(
+            result[0].fix.is_none(),
+            "Non-fixable tags like <span> should not have a fix"
+        );
     }
 
     #[test]
@@ -1059,39 +1326,36 @@ mod tests {
 
     #[test]
     fn test_md033_quick_fix_self_closing_tag() {
-        // Test Quick Fix for self-closing tags - removes tag (no content)
+        // Test that self-closing tags with fix=false (default) do NOT get a fix
         let rule = MD033NoInlineHtml::default();
         let content = "Self-closing: <br/>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1, "Should find one HTML tag");
-        assert!(result[0].fix.is_some(), "Should have a fix");
-
-        let fix = result[0].fix.as_ref().unwrap();
-        assert_eq!(&content[fix.range.clone()], "<br/>");
-        assert_eq!(fix.replacement, "");
+        // Default config has fix=false, so no fix should be provided
+        assert!(
+            result[0].fix.is_none(),
+            "Self-closing tags should not have a fix when fix config is false"
+        );
     }
 
     #[test]
     fn test_md033_quick_fix_multiple_tags() {
-        // Test Quick Fix with multiple HTML tags - keeps content for both
+        // Test that multiple tags without fix=true do NOT get fixes
+        // <span> is not a safe fixable tag, <strong> is but fix=false by default
         let rule = MD033NoInlineHtml::default();
         let content = "<span>first</span> and <strong>second</strong>";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2, "Should find two HTML tags");
-        assert!(result[0].fix.is_some(), "First tag should have a fix");
-        assert!(result[1].fix.is_some(), "Second tag should have a fix");
-
-        let fix1 = result[0].fix.as_ref().unwrap();
-        assert_eq!(&content[fix1.range.clone()], "<span>first</span>");
-        assert_eq!(fix1.replacement, "first");
-
-        let fix2 = result[1].fix.as_ref().unwrap();
-        assert_eq!(&content[fix2.range.clone()], "<strong>second</strong>");
-        assert_eq!(fix2.replacement, "second");
+        // Neither should have a fix: <span> is not fixable, <strong> is but fix=false
+        assert!(result[0].fix.is_none(), "Non-fixable <span> should not have a fix");
+        assert!(
+            result[1].fix.is_none(),
+            "<strong> should not have a fix when fix config is false"
+        );
     }
 
     #[test]
@@ -1583,14 +1847,48 @@ Regular text with <div>content</div> HTML tag.
     }
 
     #[test]
-    fn test_md033_fix_unsafe_tags_removed_not_converted() {
-        // Tags without safe markdown equivalents should be removed, not converted
+    fn test_md033_fix_unsafe_tags_not_modified() {
+        // Tags without safe markdown equivalents should NOT be modified
+        // Only safe fixable tags (em, i, strong, b, code, br, hr) get converted
         let rule = MD033NoInlineHtml::with_fix(true);
         let content = "This has <div>a div</div> content.";
         let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let fixed = rule.fix(&ctx).unwrap();
-        // Should remove tags but keep content
-        assert_eq!(fixed, "This has a div content.");
+        // <div> is not a safe fixable tag, so content should be unchanged
+        assert_eq!(fixed, "This has <div>a div</div> content.");
+    }
+
+    #[test]
+    fn test_md033_fix_img_tag_converted() {
+        // <img> tags with simple src/alt attributes are converted to markdown images
+        let rule = MD033NoInlineHtml::with_fix(true);
+        let content = "Image: <img src=\"photo.jpg\" alt=\"My Photo\">";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+        // <img> is converted to ![alt](src) format
+        assert_eq!(fixed, "Image: ![My Photo](photo.jpg)");
+    }
+
+    #[test]
+    fn test_md033_fix_img_tag_with_extra_attrs_not_converted() {
+        // <img> tags with width/height/style attributes are NOT converted
+        let rule = MD033NoInlineHtml::with_fix(true);
+        let content = "Image: <img src=\"photo.jpg\" alt=\"My Photo\" width=\"100\">";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+        // Has width attribute - not safe to convert
+        assert_eq!(fixed, "Image: <img src=\"photo.jpg\" alt=\"My Photo\" width=\"100\">");
+    }
+
+    #[test]
+    fn test_md033_fix_mixed_safe_tags() {
+        // All tags are now safe fixable (em, img, strong)
+        let rule = MD033NoInlineHtml::with_fix(true);
+        let content = "<em>italic</em> and <img src=\"x.jpg\"> and <strong>bold</strong>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+        // All are converted
+        assert_eq!(fixed, "*italic* and ![](x.jpg) and **bold**");
     }
 
     #[test]
@@ -1789,4 +2087,335 @@ Regular text with <div>content</div> HTML tag.
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "This is *emphasized* text.");
     }
+
+    // ==========================================================================
+    // Obsidian Templater Plugin Syntax Tests
+    //
+    // Templater is a popular Obsidian plugin that uses `<% ... %>` syntax for
+    // template interpolation. The `<%` pattern is NOT captured by the HTML tag
+    // parser because `%` is not a valid HTML tag name character (tags must start
+    // with a letter). This behavior is documented here with comprehensive tests.
+    //
+    // Reference: https://silentvoid13.github.io/Templater/
+    // ==========================================================================
+
+    #[test]
+    fn test_md033_templater_basic_interpolation_not_flagged() {
+        // Basic Templater interpolation: <% expr %>
+        // Should NOT be flagged because `%` is not a valid HTML tag character
+        let rule = MD033NoInlineHtml::default();
+        let content = "Today is <% tp.date.now() %> which is nice.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater basic interpolation should not be flagged as HTML. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_file_functions_not_flagged() {
+        // Templater file functions: <% tp.file.* %>
+        let rule = MD033NoInlineHtml::default();
+        let content = "File: <% tp.file.title %>\nCreated: <% tp.file.creation_date() %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater file functions should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_with_arguments_not_flagged() {
+        // Templater with function arguments
+        let rule = MD033NoInlineHtml::default();
+        let content = r#"Date: <% tp.date.now("YYYY-MM-DD") %>"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater with arguments should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_javascript_execution_not_flagged() {
+        // Templater JavaScript execution block: <%* code %>
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%* const today = tp.date.now(); tR += today; %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater JS execution block should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_dynamic_execution_not_flagged() {
+        // Templater dynamic/preview execution: <%+ expr %>
+        let rule = MD033NoInlineHtml::default();
+        let content = "Dynamic: <%+ tp.date.now() %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater dynamic execution should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_whitespace_trim_all_not_flagged() {
+        // Templater whitespace control - trim all: <%_ expr _%>
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%_ tp.date.now() _%>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater trim-all whitespace should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_whitespace_trim_newline_not_flagged() {
+        // Templater whitespace control - trim newline: <%- expr -%>
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%- tp.date.now() -%>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater trim-newline should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_combined_modifiers_not_flagged() {
+        // Templater combined whitespace and execution modifiers
+        let rule = MD033NoInlineHtml::default();
+        let contents = [
+            "<%-* const x = 1; -%>",  // trim + JS execution
+            "<%_+ tp.date.now() _%>", // trim-all + dynamic
+            "<%- tp.file.title -%>",  // trim-newline only
+            "<%_ tp.file.title _%>",  // trim-all only
+        ];
+        for content in contents {
+            let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+            let result = rule.check(&ctx).unwrap();
+            assert!(
+                result.is_empty(),
+                "Templater combined modifiers should not be flagged: {content}. Got: {result:?}"
+            );
+        }
+    }
+
+    #[test]
+    fn test_md033_templater_multiline_block_not_flagged() {
+        // Multi-line Templater JavaScript block
+        let rule = MD033NoInlineHtml::default();
+        let content = r#"<%*
+const x = 1;
+const y = 2;
+tR += x + y;
+%>"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater multi-line block should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_with_angle_brackets_in_condition_not_flagged() {
+        // Templater with angle brackets in JavaScript condition
+        // This is a key edge case: `<` inside Templater should not trigger HTML detection
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%* if (x < 5) { tR += 'small'; } %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater with angle brackets in conditions should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_mixed_with_html_only_html_flagged() {
+        // Templater syntax mixed with actual HTML - only HTML should be flagged
+        let rule = MD033NoInlineHtml::default();
+        let content = "<% tp.date.now() %> is today's date. <div>This is HTML</div>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should only flag the HTML div tag");
+        assert!(
+            result[0].message.contains("<div>"),
+            "Should flag <div>, got: {}",
+            result[0].message
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_in_heading_not_flagged() {
+        // Templater in markdown heading
+        let rule = MD033NoInlineHtml::default();
+        let content = "# <% tp.file.title %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater in heading should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_multiple_on_same_line_not_flagged() {
+        // Multiple Templater blocks on same line
+        let rule = MD033NoInlineHtml::default();
+        let content = "From <% tp.date.now() %> to <% tp.date.tomorrow() %> we have meetings.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Multiple Templater blocks should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_in_code_block_not_flagged() {
+        // Templater syntax in code blocks should not be flagged (code blocks are skipped)
+        let rule = MD033NoInlineHtml::default();
+        let content = "```\n<% tp.date.now() %>\n```";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater in code block should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_in_inline_code_not_flagged() {
+        // Templater syntax in inline code span should not be flagged
+        let rule = MD033NoInlineHtml::default();
+        let content = "Use `<% tp.date.now() %>` for current date.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater in inline code should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_also_works_in_standard_flavor() {
+        // Templater syntax should also not be flagged in Standard flavor
+        // because the HTML parser doesn't recognize `<%` as a valid tag
+        let rule = MD033NoInlineHtml::default();
+        let content = "<% tp.date.now() %> works everywhere.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater should not be flagged even in Standard flavor. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_empty_tag_not_flagged() {
+        // Empty Templater tags
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Empty Templater-like tag should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_unclosed_not_flagged() {
+        // Unclosed Templater tags - these are template errors, not HTML
+        let rule = MD033NoInlineHtml::default();
+        let content = "<% tp.date.now() without closing tag";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Unclosed Templater should not be flagged as HTML. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_with_newlines_inside_not_flagged() {
+        // Templater with newlines inside the expression
+        let rule = MD033NoInlineHtml::default();
+        let content = r#"<% tp.date.now("YYYY") +
+"-" +
+tp.date.now("MM") %>"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Templater with internal newlines should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_erb_style_tags_not_flagged() {
+        // ERB/EJS style tags (similar to Templater) are also not HTML
+        // This documents the general principle that `<%` is not valid HTML
+        let rule = MD033NoInlineHtml::default();
+        let content = "<%= variable %> and <% code %> and <%# comment %>";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "ERB/EJS style tags should not be flagged as HTML. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_templater_complex_expression_not_flagged() {
+        // Complex Templater expression with multiple function calls
+        let rule = MD033NoInlineHtml::default();
+        let content = r#"<%*
+const file = tp.file.title;
+const date = tp.date.now("YYYY-MM-DD");
+const folder = tp.file.folder();
+tR += `# ${file}\n\nCreated: ${date}\nIn: ${folder}`;
+%>"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Complex Templater expression should not be flagged. Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_md033_percent_sign_variations_not_flagged() {
+        // Various patterns starting with <% that should all be safe
+        let rule = MD033NoInlineHtml::default();
+        let patterns = [
+            "<%=",  // ERB output
+            "<%#",  // ERB comment
+            "<%%",  // Double percent
+            "<%!",  // Some template engines
+            "<%@",  // JSP directive
+            "<%--", // JSP comment
+        ];
+        for pattern in patterns {
+            let content = format!("{pattern} content %>");
+            let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard, None);
+            let result = rule.check(&ctx).unwrap();
+            assert!(
+                result.is_empty(),
+                "Pattern {pattern} should not be flagged. Got: {result:?}"
+            );
+        }
+    }
 }
