@@ -141,7 +141,7 @@ impl MD036NoEmphasisAsHeading {
             || BLOCKQUOTE_MARKER.is_match(line)
             || ctx
                 .line_info(line_num + 1)
-                .is_some_and(|info| info.in_code_block || info.in_html_comment)
+                .is_some_and(|info| info.in_code_block || info.in_html_comment || info.in_pymdown_block)
         {
             return None;
         }
