@@ -2,20 +2,12 @@ use crate::utils::fast_hash;
 use crate::utils::regex_cache::{escape_regex, get_cached_fancy_regex};
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
-use fancy_regex::Regex;
 use std::collections::{HashMap, HashSet};
-use std::sync::LazyLock;
 use std::sync::{Arc, Mutex};
 
 mod md044_config;
 use md044_config::MD044Config;
 
-static HTML_COMMENT_REGEX: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"<!--([\s\S]*?)-->").unwrap());
-// Reference definition pattern - matches [ref]: url "title"
-static REF_DEF_REGEX: LazyLock<regex::Regex> = LazyLock::new(|| {
-    regex::Regex::new(r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#).unwrap()
-});
-
 type WarningPosition = (usize, usize, String); // (line, column, found_name)
 
 /// Rule MD044: Proper names should be capitalized
@@ -196,19 +188,20 @@ impl MD044ProperNames {
         variants.into_iter().collect()
     }
 
-    // Find all name violations in the content and return positions
-    fn find_name_violations(&self, content: &str, ctx: &crate::lint_context::LintContext) -> Vec<WarningPosition> {
+    // Find all name violations in the content and return positions.
+    // `content_lower` is the pre-computed lowercase version of `content` to avoid redundant allocations.
+    fn find_name_violations(
+        &self,
+        content: &str,
+        ctx: &crate::lint_context::LintContext,
+        content_lower: &str,
+    ) -> Vec<WarningPosition> {
         // Early return: if no names configured or content is empty
         if self.config.names.is_empty() || content.is_empty() || self.combined_pattern.is_none() {
             return Vec::new();
         }
 
         // Early return: quick check if any of the configured names might be in content
-        let content_lower = if content.is_ascii() {
-            content.to_ascii_lowercase()
-        } else {
-            content.to_lowercase()
-        };
         let has_potential_matches = self.name_variants.iter().any(|name| content_lower.contains(name));
 
         if !has_potential_matches {
@@ -258,15 +251,8 @@ impl MD044ProperNames {
                 continue;
             }
 
-            // Check if we should skip HTML comments
-            let in_html_comment = if !self.config.html_comments {
-                // Check if this position is within an HTML comment
-                self.is_in_html_comment(content, line_info.byte_offset)
-            } else {
-                false
-            };
-
-            if in_html_comment {
+            // Skip HTML comments using pre-computed line flag
+            if !self.config.html_comments && line_info.in_html_comment {
                 continue;
             }
 
@@ -275,6 +261,11 @@ impl MD044ProperNames {
                 continue;
             }
 
+            // Skip Obsidian comments (Obsidian flavor)
+            if line_info.in_obsidian_comment {
+                continue;
+            }
+
             // Early return: skip lines that don't contain any potential matches
             let line_lower = line.to_lowercase();
             let has_line_matches = self.name_variants.iter().any(|name| line_lower.contains(name));
@@ -293,8 +284,8 @@ impl MD044ProperNames {
                         let start_pos = cap.start();
                         let end_pos = cap.end();
 
-                        if !self.is_at_word_boundary(line, start_pos, true)
-                            || !self.is_at_word_boundary(line, end_pos, false)
+                        if !Self::is_at_word_boundary(line, start_pos, true)
+                            || !Self::is_at_word_boundary(line, end_pos, false)
                         {
                             continue; // Not at word boundary
                         }
@@ -307,9 +298,9 @@ impl MD044ProperNames {
                             }
                         }
 
-                        // Skip if in link (inline links, reference links, or reference definitions)
+                        // Skip if in link URL or reference definition
                         let byte_pos = line_info.byte_offset + cap.start();
-                        if self.is_in_link(ctx, byte_pos) {
+                        if Self::is_in_link(ctx, byte_pos) {
                             continue;
                         }
 
@@ -335,40 +326,57 @@ impl MD044ProperNames {
         violations
     }
 
-    // Check if a byte position is within an HTML comment
-    fn is_in_html_comment(&self, content: &str, byte_pos: usize) -> bool {
-        for m in HTML_COMMENT_REGEX.find_iter(content).flatten() {
-            if m.start() <= byte_pos && byte_pos < m.end() {
-                return true;
-            }
-        }
-        false
-    }
+    /// Check if a byte position is within a link URL (not link text)
+    ///
+    /// Link text should be checked for proper names, but URLs should be skipped.
+    /// For `[text](url)` - check text, skip url
+    /// For `[text][ref]` - check text, skip reference portion
+    /// For `[[text]]` (WikiLinks) - check text, skip brackets
+    fn is_in_link(ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
+        use pulldown_cmark::LinkType;
 
-    /// Check if a byte position is within a link (inline links, reference links, or reference definitions)
-    fn is_in_link(&self, ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
-        // Check inline and reference links
-        for link in &ctx.links {
-            if link.byte_offset <= byte_pos && byte_pos < link.byte_end {
+        // Binary search links (sorted by byte_offset) to find candidate containing byte_pos
+        let link_idx = ctx.links.partition_point(|link| link.byte_offset <= byte_pos);
+        if link_idx > 0 {
+            let link = &ctx.links[link_idx - 1];
+            if byte_pos < link.byte_end {
+                // WikiLinks [[text]] start with '[[', regular links [text] start with '['
+                let text_start = if matches!(link.link_type, LinkType::WikiLink { .. }) {
+                    link.byte_offset + 2
+                } else {
+                    link.byte_offset + 1
+                };
+                let text_end = text_start + link.text.len();
+
+                // If position is within the text portion, don't skip
+                if byte_pos >= text_start && byte_pos < text_end {
+                    return false;
+                }
+                // Position is in the URL/reference portion, skip it
                 return true;
             }
         }
 
-        // Check images (which use similar syntax)
-        for image in &ctx.images {
-            if image.byte_offset <= byte_pos && byte_pos < image.byte_end {
+        // Binary search images (sorted by byte_offset) to find candidate containing byte_pos
+        let image_idx = ctx.images.partition_point(|img| img.byte_offset <= byte_pos);
+        if image_idx > 0 {
+            let image = &ctx.images[image_idx - 1];
+            if byte_pos < image.byte_end {
+                // Image starts with '![' so alt text starts at byte_offset + 2
+                let alt_start = image.byte_offset + 2;
+                let alt_end = alt_start + image.alt_text.len();
+
+                // If position is within the alt text portion, don't skip
+                if byte_pos >= alt_start && byte_pos < alt_end {
+                    return false;
+                }
+                // Position is in the URL/reference portion, skip it
                 return true;
             }
         }
 
-        // Check reference definitions [ref]: url "title" using regex pattern
-        for m in REF_DEF_REGEX.find_iter(ctx.content) {
-            if m.start() <= byte_pos && byte_pos < m.end() {
-                return true;
-            }
-        }
-
-        false
+        // Check pre-computed reference definitions
+        ctx.is_in_reference_def(byte_pos)
     }
 
     // Check if a character is a word boundary (handles Unicode)
@@ -376,30 +384,26 @@ impl MD044ProperNames {
         !c.is_alphanumeric()
     }
 
-    // Check if position is at a word boundary
-    fn is_at_word_boundary(&self, content: &str, pos: usize, is_start: bool) -> bool {
-        let chars: Vec<char> = content.chars().collect();
-        let char_indices: Vec<(usize, char)> = content.char_indices().collect();
-
-        // Find the character position
-        let char_pos = char_indices.iter().position(|(idx, _)| *idx == pos);
-        if char_pos.is_none() {
-            return true; // If we can't find position, assume boundary
-        }
-        let char_pos = char_pos.unwrap();
-
+    // Check if position is at a word boundary using O(1) byte-level lookups
+    fn is_at_word_boundary(content: &str, pos: usize, is_start: bool) -> bool {
         if is_start {
-            // Check character before position
-            if char_pos == 0 {
-                return true; // Start of string
+            if pos == 0 {
+                return true;
+            }
+            // Get the character immediately before `pos`
+            match content[..pos].chars().next_back() {
+                None => true,
+                Some(c) => Self::is_word_boundary_char(c),
             }
-            Self::is_word_boundary_char(chars[char_pos - 1])
         } else {
-            // Check character after position
-            if char_pos >= chars.len() {
-                return true; // End of string
+            if pos >= content.len() {
+                return true;
+            }
+            // Get the character at `pos`
+            match content[pos..].chars().next() {
+                None => true,
+                Some(c) => Self::is_word_boundary_char(c),
             }
-            Self::is_word_boundary_char(chars[char_pos])
         }
     }
 
@@ -443,13 +447,13 @@ impl Rule for MD044ProperNames {
         if self.config.names.is_empty() {
             return true;
         }
-        // Quick check if any configured names exist (case-insensitive)
-        let content_lower = ctx.content.to_lowercase();
-        !self
-            .config
-            .names
-            .iter()
-            .any(|name| content_lower.contains(&name.to_lowercase()))
+        // Quick check if any configured name variants exist (case-insensitive)
+        let content_lower = if ctx.content.is_ascii() {
+            ctx.content.to_ascii_lowercase()
+        } else {
+            ctx.content.to_lowercase()
+        };
+        !self.name_variants.iter().any(|name| content_lower.contains(name))
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
@@ -458,39 +462,22 @@ impl Rule for MD044ProperNames {
             return Ok(Vec::new());
         }
 
-        // Early return: quick check if any of the configured names might be in content
-        let content_lower = content.to_lowercase();
-        let has_potential_matches = self.config.names.iter().any(|name| {
-            let name_lower = name.to_lowercase();
-            let name_no_dots = name_lower.replace('.', "");
+        // Compute lowercase content once and reuse across all checks
+        let content_lower = if content.is_ascii() {
+            content.to_ascii_lowercase()
+        } else {
+            content.to_lowercase()
+        };
 
-            // Check direct match
-            if content_lower.contains(&name_lower) || content_lower.contains(&name_no_dots) {
-                return true;
-            }
-
-            // Also check ASCII-normalized version
-            let ascii_normalized = Self::ascii_normalize(&name_lower);
-
-            if ascii_normalized != name_lower {
-                if content_lower.contains(&ascii_normalized) {
-                    return true;
-                }
-                let ascii_no_dots = ascii_normalized.replace('.', "");
-                if ascii_normalized != ascii_no_dots && content_lower.contains(&ascii_no_dots) {
-                    return true;
-                }
-            }
-
-            false
-        });
+        // Early return: use pre-computed name_variants for the quick check
+        let has_potential_matches = self.name_variants.iter().any(|name| content_lower.contains(name));
 
         if !has_potential_matches {
             return Ok(Vec::new());
         }
 
         let line_index = &ctx.line_index;
-        let violations = self.find_name_violations(content, ctx);
+        let violations = self.find_name_violations(content, ctx, &content_lower);
 
         let warnings = violations
             .into_iter()
@@ -520,7 +507,12 @@ impl Rule for MD044ProperNames {
             return Ok(content.to_string());
         }
 
-        let violations = self.find_name_violations(content, ctx);
+        let content_lower = if content.is_ascii() {
+            content.to_ascii_lowercase()
+        } else {
+            content.to_lowercase()
+        };
+        let violations = self.find_name_violations(content, ctx, &content_lower);
         if violations.is_empty() {
             return Ok(content.to_string());
         }
@@ -1049,7 +1041,7 @@ More JavaScript."#;
     }
 
     #[test]
-    fn test_proper_names_in_links_not_flagged() {
+    fn test_proper_names_in_link_text_are_flagged() {
         let rule = MD044ProperNames::new(
             vec!["JavaScript".to_string(), "Node.js".to_string(), "Python".to_string()],
             true,
@@ -1070,21 +1062,47 @@ Real python should be flagged too.
         let ctx = create_context(content);
         let result = rule.check(&ctx).unwrap();
 
-        // Only the real standalone proper names should be flagged
-        assert_eq!(
-            result.len(),
-            2,
-            "Expected exactly 2 warnings for standalone proper names"
+        // Link text should be checked, URLs should not be checked
+        // Line 1: [javascript documentation] - "javascript" should be flagged
+        // Line 3: [node.js homepage] - "node.js" should be flagged (matches "Node.js")
+        // Line 3: [python tutorial] - "python" should be flagged
+        // Line 5: standalone javascript
+        // Line 9: standalone python
+        assert_eq!(result.len(), 5, "Expected 5 warnings: 3 in link text + 2 standalone");
+
+        // Verify line numbers for link text warnings
+        let line_1_warnings: Vec<_> = result.iter().filter(|w| w.line == 1).collect();
+        assert_eq!(line_1_warnings.len(), 1);
+        assert!(
+            line_1_warnings[0]
+                .message
+                .contains("'javascript' should be 'JavaScript'")
         );
-        assert!(result[0].message.contains("'javascript' should be 'JavaScript'"));
-        assert!(result[1].message.contains("'python' should be 'Python'"));
-        // Should be on lines with standalone instances
-        assert!(result[0].line == 5); // "Real javascript should be flagged."
-        assert!(result[1].line == 9); // "Real python should be flagged too."
+
+        let line_3_warnings: Vec<_> = result.iter().filter(|w| w.line == 3).collect();
+        assert_eq!(line_3_warnings.len(), 2); // node.js and python
+
+        // Standalone warnings
+        assert!(result.iter().any(|w| w.line == 5 && w.message.contains("'javascript'")));
+        assert!(result.iter().any(|w| w.line == 9 && w.message.contains("'python'")));
     }
 
     #[test]
-    fn test_proper_names_in_images_not_flagged() {
+    fn test_link_urls_not_flagged() {
+        let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
+
+        // URL contains "javascript" but should NOT be flagged
+        let content = r#"[Link Text](https://javascript.info/guide)"#;
+
+        let ctx = create_context(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // URL should not be checked
+        assert!(result.is_empty(), "URLs should not be checked for proper names");
+    }
+
+    #[test]
+    fn test_proper_names_in_image_alt_text_are_flagged() {
         let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
 
         let content = r#"Here is a ![javascript logo](javascript.png "javascript icon") image.
@@ -1094,14 +1112,32 @@ Real javascript should be flagged."#;
         let ctx = create_context(content);
         let result = rule.check(&ctx).unwrap();
 
-        // Only the standalone proper name should be flagged
-        assert_eq!(result.len(), 1, "Expected exactly 1 warning for standalone proper name");
+        // Image alt text should be checked, URL and title should not be checked
+        // Line 1: ![javascript logo] - "javascript" should be flagged
+        // Line 3: standalone javascript
+        assert_eq!(result.len(), 2, "Expected 2 warnings: 1 in alt text + 1 standalone");
         assert!(result[0].message.contains("'javascript' should be 'JavaScript'"));
-        assert!(result[0].line == 3); // "Real javascript should be flagged."
+        assert!(result[0].line == 1); // "![javascript logo]"
+        assert!(result[1].message.contains("'javascript' should be 'JavaScript'"));
+        assert!(result[1].line == 3); // "Real javascript should be flagged."
     }
 
     #[test]
-    fn test_proper_names_in_reference_definitions_not_flagged() {
+    fn test_image_urls_not_flagged() {
+        let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
+
+        // URL contains "javascript" but should NOT be flagged
+        let content = r#"![Logo](https://javascript.info/logo.png)"#;
+
+        let ctx = create_context(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // Image URL should not be checked
+        assert!(result.is_empty(), "Image URLs should not be checked for proper names");
+    }
+
+    #[test]
+    fn test_reference_link_text_flagged_but_definition_not() {
         let rule = MD044ProperNames::new(vec!["JavaScript".to_string(), "TypeScript".to_string()], true);
 
         let content = r#"Check the [javascript guide][js-ref] for details.
@@ -1113,9 +1149,52 @@ Real javascript should be flagged.
         let ctx = create_context(content);
         let result = rule.check(&ctx).unwrap();
 
-        // Only the standalone proper name should be flagged
-        assert_eq!(result.len(), 1, "Expected exactly 1 warning for standalone proper name");
-        assert!(result[0].message.contains("'javascript' should be 'JavaScript'"));
-        assert!(result[0].line == 3); // "Real javascript should be flagged."
+        // Link text should be checked, reference definitions should not
+        // Line 1: [javascript guide] - should be flagged
+        // Line 3: standalone javascript - should be flagged
+        // Line 5: reference definition - should NOT be flagged
+        assert_eq!(result.len(), 2, "Expected 2 warnings: 1 in link text + 1 standalone");
+        assert!(result.iter().any(|w| w.line == 1 && w.message.contains("'javascript'")));
+        assert!(result.iter().any(|w| w.line == 3 && w.message.contains("'javascript'")));
+    }
+
+    #[test]
+    fn test_reference_definitions_not_flagged() {
+        let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
+
+        // Reference definition should NOT be flagged
+        let content = r#"[js-ref]: https://javascript.info/guide"#;
+
+        let ctx = create_context(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // Reference definition URLs should not be checked
+        assert!(result.is_empty(), "Reference definitions should not be checked");
+    }
+
+    #[test]
+    fn test_wikilinks_text_is_flagged() {
+        let rule = MD044ProperNames::new(vec!["JavaScript".to_string()], true);
+
+        // WikiLinks [[destination]] should have their text checked
+        let content = r#"[[javascript]]
+
+Regular javascript here.
+
+[[JavaScript|display text]]"#;
+
+        let ctx = create_context(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // Line 1: [[javascript]] - should be flagged (WikiLink text)
+        // Line 3: standalone javascript - should be flagged
+        // Line 5: [[JavaScript|display text]] - correct capitalization, no flag
+        assert_eq!(result.len(), 2, "Expected 2 warnings: 1 in WikiLink + 1 standalone");
+        assert!(
+            result
+                .iter()
+                .any(|w| w.line == 1 && w.column == 3 && w.message.contains("'javascript'"))
+        );
+        assert!(result.iter().any(|w| w.line == 3 && w.message.contains("'javascript'")));
     }
 }
