@@ -107,7 +107,8 @@ impl Rule for MD049EmphasisStyle {
         // Collect all emphasis from the document
         let mut emphasis_info = vec![];
 
-        // Process content lines, automatically skipping front matter, code blocks, HTML comments, MDX constructs, and math blocks
+        // Process content lines, automatically skipping front matter, code blocks, HTML comments,
+        // MDX constructs, math blocks, and Obsidian comments
         // Math blocks contain LaTeX syntax where _ and * have special meaning
         for line in ctx
             .filtered_lines()
@@ -117,6 +118,7 @@ impl Rule for MD049EmphasisStyle {
             .skip_jsx_expressions()
             .skip_mdx_comments()
             .skip_math_blocks()
+            .skip_obsidian_comments()
         {
             // Skip if the line doesn't contain any emphasis markers
             if !line.content.contains('*') && !line.content.contains('_') {
@@ -129,8 +131,12 @@ impl Rule for MD049EmphasisStyle {
         }
 
         // Filter out emphasis markers that are inside links or MkDocs markup
-        let lines: Vec<&str> = ctx.content.lines().collect();
+        let lines = ctx.raw_lines();
         emphasis_info.retain(|(line_num, col, abs_pos, _, _)| {
+            // Skip emphasis inside Obsidian comments
+            if ctx.is_in_obsidian_comment(*abs_pos) {
+                return false;
+            }
             // Skip if inside a link
             if self.is_in_link(ctx, *abs_pos) {
                 return false;
@@ -392,4 +398,18 @@ This should be _flagged_ since we're using asterisk style.
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("Emphasis should use * instead of _"));
     }
+
+    #[test]
+    fn test_obsidian_inline_comment_emphasis_ignored() {
+        // Emphasis inside Obsidian comments should be ignored
+        let rule = MD049EmphasisStyle::new(EmphasisStyle::Asterisk);
+        let content = "Visible %%_hidden_%% text.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Should ignore emphasis inside Obsidian comments. Got: {result:?}"
+        );
+    }
 }
