@@ -181,15 +181,18 @@ impl MD055TablePipeStyle {
         // Handle list context if present
         if let Some(ref list_ctx) = table_block.list_context {
             if table_line_index == 0 {
-                // Header line: extract list prefix
-                let (list_prefix, content, _) = TableUtils::extract_list_prefix(after_bq);
-                let fixed_content = self.fix_table_content(content.trim(), target_style);
+                // Header line: strip list prefix (handles both markers and indentation)
+                let stripped = after_bq
+                    .strip_prefix(&list_ctx.list_prefix)
+                    .unwrap_or_else(|| TableUtils::extract_list_prefix(after_bq).1);
+                let fixed_content = self.fix_table_content(stripped.trim(), target_style);
 
                 // Restore prefixes: blockquote + list prefix + fixed content
-                if bq_prefix.is_empty() && list_prefix.is_empty() {
+                let lp = &list_ctx.list_prefix;
+                if bq_prefix.is_empty() && lp.is_empty() {
                     fixed_content
                 } else {
-                    format!("{bq_prefix}{list_prefix}{fixed_content}")
+                    format!("{bq_prefix}{lp}{fixed_content}")
                 }
             } else {
                 // Continuation lines: strip indentation, then restore it
@@ -306,13 +309,12 @@ impl Rule for MD055TablePipeStyle {
     }
 
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
-        let content = ctx.content;
         let line_index = &ctx.line_index;
         let mut warnings = Vec::new();
 
         // Early return handled by should_skip()
 
-        let lines: Vec<&str> = content.lines().collect();
+        let lines = ctx.raw_lines();
 
         // Get the configured style explicitly and validate it
         let configured_style = match self.config.style.as_str() {
@@ -333,7 +335,7 @@ impl Rule for MD055TablePipeStyle {
             // First pass: determine the table's style for "consistent" mode
             // Count all rows to determine most prevalent style (prevalence-based approach)
             let table_style = if configured_style == "consistent" {
-                self.determine_table_style(table_block, &lines)
+                self.determine_table_style(table_block, lines)
             } else {
                 None
             };
@@ -417,8 +419,7 @@ impl Rule for MD055TablePipeStyle {
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
-        let content = ctx.content;
-        let lines: Vec<&str> = content.lines().collect();
+        let lines = ctx.raw_lines();
 
         // Use the configured style but validate it first
         let configured_style = match self.config.style.as_str() {
@@ -442,7 +443,7 @@ impl Rule for MD055TablePipeStyle {
             // First pass: determine the table's style for "consistent" mode
             // Count all rows to determine most prevalent style (prevalence-based approach)
             let table_style = if configured_style == "consistent" {
-                self.determine_table_style(table_block, &lines)
+                self.determine_table_style(table_block, lines)
             } else {
                 None
             };
@@ -469,7 +470,7 @@ impl Rule for MD055TablePipeStyle {
 
         let mut fixed = result_lines.join("\n");
         // Preserve trailing newline if original content had one
-        if content.ends_with('\n') && !fixed.ends_with('\n') {
+        if ctx.content.ends_with('\n') && !fixed.ends_with('\n') {
             fixed.push('\n');
         }
         Ok(fixed)
