@@ -796,7 +796,7 @@ impl Rule for MD063HeadingCapitalization {
             return Ok(content.to_string());
         }
 
-        let lines: Vec<&str> = content.lines().collect();
+        let lines = ctx.raw_lines();
         let mut fixed_lines: Vec<String> = lines.iter().map(|&s| s.to_string()).collect();
 
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
