@@ -241,25 +241,36 @@ impl MD064NoMultipleConsecutiveSpaces {
         before == ":"
     }
 
-    /// Check if the match is inside a task list checkbox
-    /// Pattern: - [ ]  or - [x]  (spaces after checkbox)
-    fn is_after_task_checkbox(&self, line: &str, match_start: usize) -> bool {
+    /// Check if the match is immediately after a task list checkbox.
+    /// Standard GFM: only `[ ]`, `[x]`, `[X]` are valid checkboxes.
+    /// Obsidian flavor: any single character inside brackets is a valid checkbox
+    /// (e.g., `[/]`, `[-]`, `[>]`, `[✓]`).
+    fn is_after_task_checkbox(&self, line: &str, match_start: usize, flavor: crate::config::MarkdownFlavor) -> bool {
         let before = line[..match_start].trim_start();
 
-        // Task list patterns: *, -, + followed by [ ], [x], or [X]
-        // Examples: "- [ ]", "* [x]", "+ [X]"
-        if before.len() >= 4 {
-            let patterns = [
-                "- [ ]", "- [x]", "- [X]", "* [ ]", "* [x]", "* [X]", "+ [ ]", "+ [x]", "+ [X]",
-            ];
-            for pattern in patterns {
-                if before == pattern {
-                    return true;
+        // Zero-allocation iterator-based check for: marker + space + '[' + char + ']'
+        let mut chars = before.chars();
+        let pattern = (
+            chars.next(),
+            chars.next(),
+            chars.next(),
+            chars.next(),
+            chars.next(),
+            chars.next(),
+        );
+
+        match pattern {
+            (Some('*' | '-' | '+'), Some(' '), Some('['), Some(c), Some(']'), None) => {
+                if flavor == crate::config::MarkdownFlavor::Obsidian {
+                    // Obsidian: any single character is a valid checkbox state
+                    true
+                } else {
+                    // Standard GFM: only space, 'x', or 'X' are valid
+                    matches!(c, ' ' | 'x' | 'X')
                 }
             }
+            _ => false,
         }
-
-        false
     }
 
     /// Check if this is a table row without outer pipes (GFM extension)
@@ -317,7 +328,7 @@ impl Rule for MD064NoMultipleConsecutiveSpaces {
         let code_spans: Arc<Vec<crate::lint_context::CodeSpan>> = ctx.code_spans();
         let line_index = &ctx.line_index;
 
-        // Process content lines, automatically skipping front matter, code blocks, HTML
+        // Process content lines, automatically skipping front matter, code blocks, HTML, PyMdown blocks, and Obsidian comments
         for line in ctx
             .filtered_lines()
             .skip_front_matter()
@@ -326,6 +337,8 @@ impl Rule for MD064NoMultipleConsecutiveSpaces {
             .skip_html_comments()
             .skip_mkdocstrings()
             .skip_esm_blocks()
+            .skip_pymdown_blocks()
+            .skip_obsidian_comments()
         {
             // Quick check: skip if line doesn't contain double spaces
             if !line.content.contains("  ") {
@@ -392,7 +405,7 @@ impl Rule for MD064NoMultipleConsecutiveSpaces {
                 }
 
                 // Skip spaces after task list checkboxes
-                if self.is_after_task_checkbox(line.content, match_start) {
+                if self.is_after_task_checkbox(line.content, match_start, ctx.flavor) {
                     continue;
                 }
 
@@ -889,6 +902,177 @@ Normal paragraph.
         assert!(result.is_empty());
     }
 
+    #[test]
+    fn test_skip_extended_task_checkbox_spaces_obsidian() {
+        // Extended checkboxes are only recognized in Obsidian flavor
+        let rule = MD064NoMultipleConsecutiveSpaces::new();
+
+        // Extended Obsidian checkboxes: [/] in progress
+        let content = "- [/]  In progress task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [/] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [-] cancelled
+        let content = "- [-]  Cancelled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [-] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [>] deferred
+        let content = "- [>]  Deferred task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [>] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [<] scheduled
+        let content = "- [<]  Scheduled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [<] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [?] question
+        let content = "- [?]  Question task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [?] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [!] important
+        let content = "- [!]  Important task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [!] checkbox in Obsidian");
+
+        // Extended Obsidian checkboxes: [*] star/highlight
+        let content = "- [*]  Starred task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip [*] checkbox in Obsidian");
+
+        // With asterisk list marker and extended checkbox
+        let content = "* [/]  In progress with asterisk\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip extended checkbox with * marker");
+
+        // With plus list marker and extended checkbox
+        let content = "+ [-]  Cancelled with plus\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip extended checkbox with + marker");
+
+        // Multi-byte UTF-8 checkboxes (Unicode checkmarks)
+        let content = "- [✓]  Completed with checkmark\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip Unicode checkmark [✓]");
+
+        let content = "- [✗]  Failed with X mark\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip Unicode X mark [✗]");
+
+        let content = "- [→]  Forwarded with arrow\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Should skip Unicode arrow [→]");
+    }
+
+    #[test]
+    fn test_flag_extended_checkboxes_in_standard_flavor() {
+        // Extended checkboxes should be flagged in Standard flavor (GFM only recognizes [ ], [x], [X])
+        let rule = MD064NoMultipleConsecutiveSpaces::new();
+
+        let content = "- [/]  In progress task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should flag [/] in Standard flavor");
+
+        let content = "- [-]  Cancelled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should flag [-] in Standard flavor");
+
+        let content = "- [✓]  Unicode checkbox\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should flag [✓] in Standard flavor");
+    }
+
+    #[test]
+    fn test_extended_checkboxes_with_indentation() {
+        let rule = MD064NoMultipleConsecutiveSpaces::new();
+
+        // Space-indented task list with extended checkbox (Obsidian)
+        // 2 spaces is not enough for code block, so this is clearly a list item
+        let content = "  - [/]  In progress task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should skip space-indented extended checkbox in Obsidian"
+        );
+
+        // 3 spaces - still not a code block
+        let content = "   - [-]  Cancelled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should skip 3-space indented extended checkbox in Obsidian"
+        );
+
+        // Tab-indented with list context (parent list makes nested item clear)
+        // Without context, a tab-indented line is treated as a code block
+        let content = "- Parent item\n\t- [/]  In progress task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Obsidian, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should skip tab-indented nested extended checkbox in Obsidian"
+        );
+
+        // Space-indented extended checkbox should be flagged in Standard flavor
+        let content = "  - [/]  In progress task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should flag indented [/] in Standard flavor");
+
+        // 3-space indented extended checkbox should be flagged in Standard flavor
+        let content = "   - [-]  Cancelled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Should flag 3-space indented [-] in Standard flavor");
+
+        // Tab-indented nested list should be flagged in Standard flavor
+        let content = "- Parent item\n\t- [-]  Cancelled task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(
+            result.len(),
+            1,
+            "Should flag tab-indented nested [-] in Standard flavor"
+        );
+
+        // Standard checkboxes should still work when indented (both flavors)
+        let content = "  - [x]  Completed task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should skip indented standard [x] checkbox in Standard flavor"
+        );
+
+        // Tab-indented with list context and standard checkbox
+        let content = "- Parent\n\t- [ ]  Pending task\n";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should skip tab-indented nested standard [ ] checkbox"
+        );
+    }
+
     #[test]
     fn test_skip_table_without_outer_pipes() {
         let rule = MD064NoMultipleConsecutiveSpaces::new();
