@@ -61,6 +61,7 @@ impl Rule for MD069NoDuplicateListMarkers {
             .skip_code_blocks()
             .skip_html_blocks()
             .skip_html_comments()
+            .skip_obsidian_comments()
         {
             let line_num = filtered_line.line_num;
             let line = filtered_line.content;
@@ -131,7 +132,7 @@ impl Rule for MD069NoDuplicateListMarkers {
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let mut result = String::with_capacity(ctx.content.len());
-        let lines: Vec<&str> = ctx.content.lines().collect();
+        let lines = ctx.raw_lines();
 
         for (i, line) in lines.iter().enumerate() {
             let line_num = i + 1; // 1-indexed for inline config
