@@ -20,16 +20,19 @@ pub mod mkdocs_abbreviations;
 pub mod mkdocs_admonitions;
 pub mod mkdocs_attr_list;
 pub mod mkdocs_common;
+pub mod mkdocs_config;
 pub mod mkdocs_critic;
 pub mod mkdocs_definition_lists;
 pub mod mkdocs_extensions;
 pub mod mkdocs_footnotes;
+pub mod mkdocs_html_markdown;
 pub mod mkdocs_icons;
 pub mod mkdocs_patterns;
 pub mod mkdocs_snippets;
 pub mod mkdocs_tabs;
 pub mod mkdocs_test_utils;
 pub mod mkdocstrings_refs;
+pub mod pymdown_blocks;
 pub mod quarto_divs;
 pub mod range_utils;
 pub mod regex_cache;
