@@ -271,7 +271,7 @@ pub struct FileIndex {
     pub reference_links: Vec<ReferenceLinkIndex>,
     /// Cross-file links in this file (for MD051 cross-file validation)
     pub cross_file_links: Vec<CrossFileLinkIndex>,
-    /// Defined reference IDs (e.g., from [ref]: url definitions)
+    /// Defined reference IDs (e.g., from `[ref]: url` definitions)
     /// Used to filter out reference links that have explicit definitions
     pub defined_references: HashSet<String>,
     /// Content hash for change detection
@@ -279,7 +279,7 @@ pub struct FileIndex {
     /// O(1) anchor lookup: lowercased anchor → heading index
     /// Includes both auto-generated and custom anchors
     anchor_to_heading: HashMap<String, usize>,
-    /// HTML anchors defined via <a id="..."> or <element id="..."> tags
+    /// HTML anchors defined via `<a id="...">` or `<element id="...">` tags
     /// Stored lowercase for case-insensitive matching
     html_anchors: HashSet<String>,
     /// Attribute anchors defined via { #id } syntax (kramdown/MkDocs attr_list)
@@ -289,8 +289,10 @@ pub struct FileIndex {
     /// Rules disabled for the entire file (from inline comments)
     /// Used by cross-file rules to respect inline disable directives
     pub file_disabled_rules: HashSet<String>,
-    /// Rules disabled at specific lines (line number -> set of rule names)
-    /// Merges both persistent disables and line-specific disables
+    /// Persistent disable/enable state transitions, sorted by line number.
+    /// Each entry: (line, disabled_rules, enabled_rules). Use binary search to query.
+    pub persistent_transitions: Vec<(usize, HashSet<String>, HashSet<String>)>,
+    /// Rules disabled at specific lines via disable-line / disable-next-line
     pub line_disabled_rules: HashMap<usize, HashSet<String>>,
 }
 
@@ -310,7 +312,7 @@ pub struct HeadingIndex {
 /// Information about a reference link for cross-file analysis
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct ReferenceLinkIndex {
-    /// The reference ID (the part in [text][ref])
+    /// The reference ID (the part in `[text][ref]`)
     pub reference_id: String,
     /// Line number (1-indexed)
     pub line: usize,
@@ -695,12 +697,20 @@ impl FileIndex {
         self.headings.push(heading);
     }
 
+    /// Add an alternative anchor that resolves to an existing heading.
+    /// Used for platform-specific anchor conventions (e.g., Python-Markdown `_N` dedup).
+    pub fn add_anchor_alias(&mut self, anchor: String, heading_index: usize) {
+        if heading_index < self.headings.len() {
+            self.anchor_to_heading.insert(anchor.to_lowercase(), heading_index);
+        }
+    }
+
     /// Check if an anchor exists in this file (O(1) lookup)
     ///
     /// Returns true if the anchor matches any of:
     /// - Auto-generated heading anchors
     /// - Custom heading anchors (from {#id} syntax on headings)
-    /// - HTML anchors (from <a id="..."> or <element id="...">)
+    /// - HTML anchors (from `<a id="...">` or `<element id="...">`)
     /// - Attribute anchors (from { #id } syntax on non-heading elements)
     ///
     /// Matching is case-insensitive. URL-encoded anchors (e.g., CJK characters
@@ -729,7 +739,7 @@ impl FileIndex {
         false
     }
 
-    /// Add an HTML anchor (from <a id="..."> or <element id="..."> tags)
+    /// Add an HTML anchor (from `<a id="...">` or `<element id="...">` tags)
     pub fn add_html_anchor(&mut self, anchor: String) {
         if !anchor.is_empty() {
             self.html_anchors.insert(anchor.to_lowercase());
@@ -767,9 +777,32 @@ impl FileIndex {
             return true;
         }
 
-        // Check line-specific disables
-        if let Some(rules) = self.line_disabled_rules.get(&line) {
-            return rules.contains("*") || rules.contains(rule_name);
+        // Check line-specific disables (disable-line / disable-next-line)
+        if let Some(rules) = self.line_disabled_rules.get(&line)
+            && (rules.contains("*") || rules.contains(rule_name))
+        {
+            return true;
+        }
+
+        // Check persistent disable/enable transitions via binary search
+        if !self.persistent_transitions.is_empty() {
+            let idx = match self.persistent_transitions.binary_search_by_key(&line, |t| t.0) {
+                Ok(i) => Some(i),
+                Err(i) => {
+                    if i > 0 {
+                        Some(i - 1)
+                    } else {
+                        None
+                    }
+                }
+            };
+            if let Some(i) = idx {
+                let (_, ref disabled, ref enabled) = self.persistent_transitions[i];
+                if disabled.contains("*") {
+                    return !enabled.contains(rule_name);
+                }
+                return disabled.contains(rule_name);
+            }
         }
 
         false
@@ -787,7 +820,7 @@ impl FileIndex {
         }
     }
 
-    /// Add a defined reference ID (e.g., from [ref]: url)
+    /// Add a defined reference ID (e.g., from `[ref]: url`)
     pub fn add_defined_reference(&mut self, ref_id: String) {
         self.defined_references.insert(ref_id);
     }
