@@ -130,7 +130,7 @@ proptest! {
             Box::new(MD012NoMultipleBlanks::default()),
             Box::new(MD013LineLength::default()),
             Box::new(MD014CommandsShowOutput::default()),
-            Box::new(MD018NoMissingSpaceAtx),
+            Box::new(MD018NoMissingSpaceAtx::new()),
             Box::new(MD019NoMultipleSpaceAtx),
             Box::new(MD020NoMissingSpaceClosedAtx),
             Box::new(MD021NoMultipleSpaceClosedAtx),
@@ -152,7 +152,7 @@ proptest! {
             Box::new(MD037NoSpaceInEmphasis),
             Box::new(MD038NoSpaceInCode::default()),
             Box::new(MD039NoSpaceInLinks),
-            Box::new(MD040FencedCodeLanguage),
+            Box::new(MD040FencedCodeLanguage::default()),
             Box::new(MD041FirstLineHeading::default()),
             Box::new(MD042NoEmptyLinks::default()),
             Box::new(MD045NoAltText::default()),
@@ -166,6 +166,21 @@ proptest! {
             Box::new(MD055TablePipeStyle::default()),
             Box::new(MD056TableColumnCount),
             Box::new(MD058BlanksAroundTables::default()),
+            Box::new(MD059LinkText::default()),
+            Box::new(MD060TableFormat::default()),
+            Box::new(MD061ForbiddenTerms::default()),
+            Box::new(MD062LinkDestinationWhitespace),
+            Box::new(MD063HeadingCapitalization::default()),
+            Box::new(MD064NoMultipleConsecutiveSpaces::default()),
+            Box::new(MD065BlanksAroundHorizontalRules),
+            Box::new(MD066FootnoteValidation),
+            Box::new(MD067FootnoteDefinitionOrder),
+            Box::new(MD068EmptyFootnoteDefinition),
+            Box::new(MD069NoDuplicateListMarkers),
+            Box::new(MD070NestedCodeFence),
+            Box::new(MD071BlankLineAfterFrontmatter),
+            Box::new(MD072FrontmatterKeySort::default()),
+            Box::new(MD073TocValidation::default()),
         ];
 
         for rule in &rules {
@@ -228,7 +243,7 @@ proptest! {
 
     #[test]
     fn test_md018_idempotent(content in markdown_content_strategy()) {
-        let rule = MD018NoMissingSpaceAtx;
+        let rule = MD018NoMissingSpaceAtx::new();
 
         let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
         let warnings1 = rule.check(&ctx1).unwrap_or_default();
@@ -286,11 +301,6 @@ proptest! {
         prop_assert_eq!(fixed1, fixed2, "MD031 fix not idempotent");
     }
 
-    // TODO: This test found a real idempotency bug in MD032 with input like:
-    // "- \n# \n**\n2. \n# "
-    // The fix is not idempotent - it keeps adding blank lines.
-    // See formatter_idempotency_test for specific regression test.
-    #[ignore = "MD032 has known idempotency issues - see issue"]
     #[test]
     fn test_md032_idempotent(content in markdown_content_strategy()) {
         let rule = MD032BlanksAroundLists::default();
@@ -380,4 +390,109 @@ proptest! {
 
         prop_assert_eq!(fixed1, fixed2, "MD050 fix not idempotent");
     }
+
+    #[test]
+    fn test_md060_idempotent(content in markdown_content_strategy()) {
+        let rule = MD060TableFormat::default();
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD060 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md062_idempotent(content in markdown_content_strategy()) {
+        let rule = MD062LinkDestinationWhitespace;
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD062 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md063_idempotent(content in markdown_content_strategy()) {
+        let rule = MD063HeadingCapitalization::default();
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD063 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md064_idempotent(content in markdown_content_strategy()) {
+        let rule = MD064NoMultipleConsecutiveSpaces::default();
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD064 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md065_idempotent(content in markdown_content_strategy()) {
+        let rule = MD065BlanksAroundHorizontalRules;
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD065 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md069_idempotent(content in markdown_content_strategy()) {
+        let rule = MD069NoDuplicateListMarkers;
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD069 fix not idempotent");
+    }
+
+    #[test]
+    fn test_md071_idempotent(content in markdown_content_strategy()) {
+        let rule = MD071BlankLineAfterFrontmatter;
+
+        let ctx1 = LintContext::new(&content, MarkdownFlavor::Standard, None);
+        let warnings1 = rule.check(&ctx1).unwrap_or_default();
+        let fixed1 = apply_all_fixes(&content, &warnings1);
+
+        let ctx2 = LintContext::new(&fixed1, MarkdownFlavor::Standard, None);
+        let warnings2 = rule.check(&ctx2).unwrap_or_default();
+        let fixed2 = apply_all_fixes(&fixed1, &warnings2);
+
+        prop_assert_eq!(fixed1, fixed2, "MD071 fix not idempotent");
+    }
 }
